@@ -5,14 +5,15 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 DOCUMENTATION = """
-    author: Ansible Team
-    connection: libssh
+    author:
+      - Ansible Networking Team (@ansible-network)
+    name: libssh
     short_description: (Tech preview) Run tasks using libssh for ssh connection
     description:
         - Use the ansible-pylibssh python bindings to connect to targets
         - The python bindings use libssh C library (https://www.libssh.org/) to connect to targets
         - This plugin borrows a lot of settings from the ssh plugin as they both cover the same protocol.
-    version_added: "2.10"
+    version_added: 1.1.0
     options:
       remote_addr:
         description:
@@ -216,7 +217,7 @@ SFTP_CONNECTION_CACHE = {}
 
 
 class Connection(ConnectionBase):
-    """ SSH based connections with Paramiko """
+    """SSH based connections with Paramiko"""
 
     transport = "ansible.netcommon.libssh"
     _log_channel = None
@@ -279,7 +280,7 @@ class Connection(ConnectionBase):
         return proxy_command
 
     def _connect_uncached(self):
-        """ activates the connection object """
+        """activates the connection object"""
 
         if not HAS_PYLIBSSH:
             raise AnsibleError(missing_required_lib("ansible-pylibssh"))
@@ -345,7 +346,7 @@ class Connection(ConnectionBase):
         return self.ssh
 
     def exec_command(self, cmd, in_data=None, sudoable=True):
-        """ run a command on the remote host """
+        """run a command on the remote host"""
 
         super(Connection, self).exec_command(
             cmd, in_data=in_data, sudoable=sudoable
@@ -362,9 +363,9 @@ class Connection(ConnectionBase):
             self.chan = self.ssh.new_channel()
         except Exception as e:
             text_e = to_text(e)
-            msg = u"Failed to open session"
+            msg = "Failed to open session"
             if text_e:
-                msg += u": %s" % text_e
+                msg += ": %s" % text_e
             raise AnsibleConnectionFailure(to_native(msg))
 
         # sudo usually requires a PTY (cf. requiretty option), therefore
@@ -455,7 +456,7 @@ class Connection(ConnectionBase):
         return rc, out, err
 
     def put_file(self, in_path, out_path, proto="sftp"):
-        """ transfer a file from local to remote """
+        """transfer a file from local to remote"""
 
         super(Connection, self).put_file(in_path, out_path)
 
@@ -510,7 +511,7 @@ class Connection(ConnectionBase):
             return result
 
     def fetch_file(self, in_path, out_path, proto="sftp"):
-        """ save a remote file to the specified path """
+        """save a remote file to the specified path"""
 
         super(Connection, self).fetch_file(in_path, out_path)
 
@@ -553,7 +554,7 @@ class Connection(ConnectionBase):
         self._connect()
 
     def close(self):
-        """ terminate the connection """
+        """terminate the connection"""
 
         cache_key = self._cache_key()
         SSH_CONNECTION_CACHE.pop(cache_key, None)
