@@ -64,12 +64,12 @@ class NetconfConnection(Connection):
 
     def __rpc__(self, name, *args, **kwargs):
         """Executes the json-rpc and returns the output received
-           from remote device.
-           :name: rpc method to be executed over connection plugin that implements jsonrpc 2.0
-           :args: Ordered list of params passed as arguments to rpc method
-           :kwargs: Dict of valid key, value pairs passed as arguments to rpc method
+        from remote device.
+        :name: rpc method to be executed over connection plugin that implements jsonrpc 2.0
+        :args: Ordered list of params passed as arguments to rpc method
+        :kwargs: Dict of valid key, value pairs passed as arguments to rpc method
 
-           For usage refer the respective connection plugin docs.
+        For usage refer the respective connection plugin docs.
         """
         self.check_rc = kwargs.pop("check_rc", True)
         self.ignore_warning = kwargs.pop("ignore_warning", True)
@@ -159,7 +159,7 @@ def remove_namespaces(data):
             "It can be installed using `pip install ncclient`"
         )
     return NCElement(
-        to_text(data.strip(), errors="surrogate_then_replace"),
+        to_text(data, errors="surrogate_then_replace").strip(),
         transform_reply(),
     ).data_xml
 
