@@ -292,8 +292,7 @@ except ImportError:
 
 
 def main():
-    """entry point for module execution
-    """
+    """entry point for module execution"""
     argument_spec = dict(
         source=dict(choices=["running", "candidate", "startup"]),
         filter=dict(type="raw"),
@@ -328,10 +327,16 @@ def main():
         filter_type = "subtree"
     elif filter_type == "xpath":
         pass
-    elif (filter_type is None) and (filter_data is not None):
-        # to maintain backward compatibility for ansible 2.9 which
-        # defaults to "subtree" filter type
-        filter_type = "subtree"
+    elif filter_type is None:
+        if filter_data is not None:
+            # to maintain backward compatibility for ansible 2.9 which
+            # defaults to "subtree" filter type
+            filter_type = "subtree"
+            module.warn(
+                "The data format of filter option value couldn't be identified, hence set to 'subtree'"
+            )
+        else:
+            pass
     elif filter_type:
         module.fail_json(
             msg="Invalid filter type detected %s for filter value %s"
