@@ -44,6 +44,7 @@ options:
     linux_profile:
         description:
             - The Linux profile suboptions.
+            - Optional, provide if you need an ssh access to the cluster nodes.
         suboptions:
             admin_username:
                 description:
@@ -99,6 +100,19 @@ options:
                     - 'VirtualMachineScaleSets'
                     - 'AvailabilitySet'
                 type: str
+            mode:
+                description:
+                    - AgentPoolMode represents mode of an agent pool.
+                    - Possible values include C(System) and C(User).
+                    - System AgentPoolMode requires a minimum VM SKU of at least 2 vCPUs and 4GB memory.
+                choices:
+                    - 'System'
+                    - 'User'
+                type: str
+            node_labels:
+                description:
+                    - Agent pool node labels to be persisted across all nodes in agent pool.
+                type: dict
             vnet_subnet_id:
                 description:
                     - Specifies the VNet's subnet identifier.
@@ -113,7 +127,7 @@ options:
                     - 3
     service_principal:
         description:
-            - The service principal suboptions.
+            - The service principal suboptions. If not provided - use system-assigned managed identity.
         suboptions:
             client_id:
                 description:
@@ -176,6 +190,27 @@ options:
                 choices:
                     - standard
                     - basic
+            outbound_type:
+                description:
+                    - How outbound traffic will be configured for a cluster.
+                type: str
+                choices:
+                    - loadBalancer
+                    - userDefinedRouting
+    api_server_access_profile:
+        description:
+            - Profile of API Access configuration.
+        suboptions:
+            authorized_ip_ranges:
+                description:
+                    - Authorized IP Ranges to kubernetes API server.
+                    - Cannot be enabled when using private cluster
+                type: list
+            enable_private_cluster:
+                description:
+                    - Whether to create the cluster as a private cluster or not.
+                    - Cannot be changed for an existing cluster.
+                type: bool
     aad_profile:
         description:
             - Profile of Azure Active Directory configuration.
@@ -190,6 +225,15 @@ options:
                 description:
                     - The AAD tenant ID to use for authentication.
                     - If not specified, will use the tenant of the deployment subscription.
+            managed:
+                description:
+                    - Whether to enable manged AAD.
+                type: bool
+                default: false
+            admin_group_object_ids:
+                description:
+                    - AAD group object IDs that will have admin role of the cluster.
+                type: str
     addon:
         description:
             - Profile of managed cluster add-on.
@@ -251,7 +295,7 @@ author:
 '''
 
 EXAMPLES = '''
-    - name: Create an AKS instance
+    - name: Create an AKS instance With A System Node Pool & A User Node Pool
       azure_rm_aks:
         name: myAKS
         resource_group: myResourceGroup
@@ -267,9 +311,19 @@ EXAMPLES = '''
         agent_pool_profiles:
           - name: default
             count: 1
-            vm_size: Standard_DS1_v2
+            vm_size: Standard_B2s
             enable_auto_scaling: True
             type: VirtualMachineScaleSets
+            mode: System
+            max_count: 3
+            min_count: 1
+            enable_rbac: yes
+          - name: user
+            count: 1
+            vm_size: Standard_D2_v2
+            enable_auto_scaling: True
+            type: VirtualMachineScaleSets
+            mode: User
             max_count: 3
             min_count: 1
             enable_rbac: yes
@@ -290,10 +344,52 @@ EXAMPLES = '''
         agent_pool_profiles:
           - name: default
             count: 5
-            vm_size: Standard_D2_v2
+            mode: System
+            vm_size: Standard_B2s
         tags:
           Environment: Production
 
+    - name: Use minimal parameters and system-assigned identity
+      azure_rm_aks:
+        name: myMinimalCluster
+        location: eastus
+        resource_group: myExistingResourceGroup
+        dns_prefix: akstest
+        agent_pool_profiles:
+          - name: default
+            count: 1
+            vm_size: Standard_D2_v2
+
+    - name: Create AKS with userDefinedRouting "Link:https://docs.microsoft.com/en-us/azure/aks/limit-egress-traffic#add-a-dnat-rule-to-azure-firewall"
+      azure_rm_aks:
+        name: "minimal{{ rpfx }}"
+        location: eastus
+        resource_group: "{{ resource_group }}"
+        kubernetes_version: "{{ versions.azure_aks_versions[0] }}"
+        dns_prefix: "aks{{ rpfx }}"
+        service_principal:
+          client_id: "{{ client_id }}"
+          client_secret: "{{ client_secret }}"
+        network_profile:
+          network_plugin: azure
+          load_balancer_sku: standard
+          outbound_type: userDefinedRouting
+          service_cidr: "10.41.0.0/16"
+          dns_service_ip: "10.41.0.10"
+          docker_bridge_cidr: "172.17.0.1/16"
+        api_server_access_profile:
+          authorized_ip_ranges:
+            - "20.106.246.252/32"
+          enable_private_cluster: no
+        agent_pool_profiles:
+          - name: default
+            count: 1
+            vm_size: Standard_B2s
+            mode: System
+            vnet_subnet_id: "{{ output.subnets[0].id }}"
+            type: VirtualMachineScaleSets
+            enable_auto_scaling: false
+
     - name: Remove a managed Azure Container Services (AKS) instance
       azure_rm_aks:
         name: myAKS
@@ -312,9 +408,11 @@ state:
            name: default
            os_disk_size_gb: Null
            os_type: Linux
+           moode: System
+           node_labels: { "environment": "dev", "release": "stable" }
            ports: Null
            storage_profile: ManagedDisks
-           vm_size: Standard_DS1_v2
+           vm_size: Standard_B2s
            vnet_subnet_id: Null
         changed: false
         dns_prefix: aks9860bdcd89
@@ -366,6 +464,7 @@ def create_aks_dict(aks):
         enable_rbac=aks.enable_rbac,
         network_profile=create_network_profiles_dict(aks.network_profile),
         aad_profile=create_aad_profiles_dict(aks.aad_profile),
+        api_server_access_profile=create_api_server_access_profile_dict(aks.api_server_access_profile),
         addon=create_addon_dict(aks.addon_profiles),
         fqdn=aks.fqdn,
         node_resource_group=aks.node_resource_group
@@ -380,7 +479,8 @@ def create_network_profiles_dict(network):
         service_cidr=network.service_cidr,
         dns_service_ip=network.dns_service_ip,
         docker_bridge_cidr=network.docker_bridge_cidr,
-        load_balancer_sku=network.load_balancer_sku
+        load_balancer_sku=network.load_balancer_sku,
+        outbound_type=network.outbound_type
     ) if network else dict()
 
 
@@ -388,6 +488,10 @@ def create_aad_profiles_dict(aad):
     return aad.as_dict() if aad else dict()
 
 
+def create_api_server_access_profile_dict(api_server):
+    return api_server.as_dict() if api_server else dict()
+
+
 def create_addon_dict(addon):
     result = dict()
     addon = addon or dict()
@@ -405,10 +509,13 @@ def create_linux_profile_dict(linuxprofile):
     :param: linuxprofile: ContainerServiceLinuxProfile with the Azure callback object
     :return: dict with the state on Azure
     '''
-    return dict(
-        ssh_key=linuxprofile.ssh.public_keys[0].key_data,
-        admin_username=linuxprofile.admin_username
-    )
+    if linuxprofile:
+        return dict(
+            ssh_key=linuxprofile.ssh.public_keys[0].key_data,
+            admin_username=linuxprofile.admin_username
+        )
+    else:
+        return None
 
 
 def create_service_principal_profile_dict(serviceprincipalprofile):
@@ -438,8 +545,10 @@ def create_agent_pool_profiles_dict(agentpoolprofiles):
         availability_zones=profile.availability_zones,
         os_type=profile.os_type,
         type=profile.type,
+        mode=profile.mode,
         enable_auto_scaling=profile.enable_auto_scaling,
         max_count=profile.max_count,
+        node_labels=profile.node_labels,
         min_count=profile.min_count,
         max_pods=profile.max_pods
     ) for profile in agentpoolprofiles] if agentpoolprofiles else None
@@ -494,8 +603,10 @@ agent_pool_profile_spec = dict(
     availability_zones=dict(type='list', elements='int', choices=[1, 2, 3]),
     os_type=dict(type='str', choices=['Linux', 'Windows']),
     type=dict(type='str', choice=['VirtualMachineScaleSets', 'AvailabilitySet']),
+    mode=dict(type='str', choice=['System', 'User'], requried=True),
     enable_auto_scaling=dict(type='bool'),
     max_count=dict(type='int'),
+    node_labels=dict(type='dict'),
     min_count=dict(type='int'),
     max_pods=dict(type='int')
 )
@@ -508,7 +619,8 @@ network_profile_spec = dict(
     service_cidr=dict(type='str'),
     dns_service_ip=dict(type='str'),
     docker_bridge_cidr=dict(type='str'),
-    load_balancer_sku=dict(type='str')
+    load_balancer_sku=dict(type='str'),
+    outbound_type=dict(type='str', default='loadBalancer', choices=['userDefinedRouting', 'loadBalancer'])
 )
 
 
@@ -516,7 +628,15 @@ aad_profile_spec = dict(
     client_app_id=dict(type='str'),
     server_app_id=dict(type='str'),
     server_app_secret=dict(type='str', no_log=True),
-    tenant_id=dict(type='str')
+    tenant_id=dict(type='str'),
+    managed=dict(type='bool', default='false'),
+    admin_group_object_ids=dict(type='str')
+)
+
+
+api_server_access_profile_spec = dict(
+    authorized_ip_ranges=dict(type='list', elements='str'),
+    enable_private_cluster=dict(type='bool'),
 )
 
 
@@ -576,6 +696,10 @@ class AzureRMManagedCluster(AzureRMModuleBase):
                 type='dict',
                 options=create_addon_profiles_spec()
             ),
+            api_server_access_profile=dict(
+                type='dict',
+                options=api_server_access_profile_spec
+            ),
             node_resource_group=dict(
                 type='str'
             )
@@ -594,12 +718,13 @@ class AzureRMManagedCluster(AzureRMModuleBase):
         self.enable_rbac = False
         self.network_profile = None
         self.aad_profile = None
+        self.api_server_access_profile = None
         self.addon = None
         self.node_resource_group = None
 
         required_if = [
             ('state', 'present', [
-             'dns_prefix', 'linux_profile', 'agent_pool_profiles', 'service_principal'])
+             'dns_prefix', 'agent_pool_profiles'])
         ]
 
         self.results = dict(changed=False)
@@ -650,7 +775,7 @@ class AzureRMManagedCluster(AzureRMModuleBase):
                             return base != new
 
                     # Cannot Update the SSH Key for now // Let service to handle it
-                    if is_property_changed('linux_profile', 'ssh_key'):
+                    if self.linux_profile and is_property_changed('linux_profile', 'ssh_key'):
                         self.log(("Linux Profile Diff SSH, Was {0} / Now {1}"
                                   .format(response['linux_profile']['ssh_key'], self.linux_profile.get('ssh_key'))))
                         to_be_updated = True
@@ -659,7 +784,7 @@ class AzureRMManagedCluster(AzureRMModuleBase):
                     # self.log("linux_profile response : {0}".format(response['linux_profile'].get('admin_username')))
                     # self.log("linux_profile self : {0}".format(self.linux_profile[0].get('admin_username')))
                     # Cannot Update the Username for now // Let service to handle it
-                    if is_property_changed('linux_profile', 'admin_username'):
+                    if self.linux_profile and is_property_changed('linux_profile', 'admin_username'):
                         self.log(("Linux Profile Diff User, Was {0} / Now {1}"
                                   .format(response['linux_profile']['admin_username'], self.linux_profile.get('admin_username'))))
                         to_be_updated = True
@@ -679,6 +804,17 @@ class AzureRMManagedCluster(AzureRMModuleBase):
                     if response['enable_rbac'] != self.enable_rbac:
                         to_be_updated = True
 
+                    if response['api_server_access_profile'] != self.api_server_access_profile and self.api_server_access_profile is not None:
+                        if self.api_server_access_profile.get('enable_private_cluster') != response['api_server_access_profile'].get('enable_private_cluster'):
+                            self.log(("Api Server Access Diff - Origin {0} / Update {1}"
+                                     .format(str(self.api_server_access_profile), str(response['api_server_access_profile']))))
+                            self.fail("The enable_private_cluster of the api server access profile cannot be updated")
+                        elif len(self.api_server_access_profile.get('authorized_ip_ranges')) != \
+                                len(response['api_server_access_profile'].get('authorized_ip_ranges')):
+                            self.log(("Api Server Access Diff - Origin {0} / Update {1}"
+                                     .format(str(self.api_server_access_profile), str(response['api_server_access_profile']))))
+                            to_be_updated = True
+
                     if self.network_profile:
                         for key in self.network_profile.keys():
                             original = response['network_profile'].get(key) or ''
@@ -715,7 +851,9 @@ class AzureRMManagedCluster(AzureRMModuleBase):
                                 vm_size = profile_self['vm_size']
                                 availability_zones = profile_self['availability_zones']
                                 enable_auto_scaling = profile_self['enable_auto_scaling']
+                                mode = profile_self['mode']
                                 max_count = profile_self['max_count']
+                                node_labels = profile_self['node_labels']
                                 min_count = profile_self['min_count']
                                 max_pods = profile_self['max_pods']
 
@@ -748,6 +886,12 @@ class AzureRMManagedCluster(AzureRMModuleBase):
                                 elif min_count is not None and profile_result['min_count'] != min_count:
                                     self.log(("Agent Profile Diff - Origin {0} / Update {1}".format(str(profile_result), str(profile_self))))
                                     to_be_updated = True
+                                elif mode is not None and profile_result['mode'] != mode:
+                                    self.log(("Agent Profile Diff - Origin {0} / Update {1}".format(str(profile_result), str(profile_self))))
+                                    to_be_updated = True
+                                elif node_labels is not None and profile_result['node_labels'] != node_labels:
+                                    self.log(("Agent Profile Diff - Origin {0} / Update {1}".format(str(profile_result), str(profile_self))))
+                                    to_be_updated = True
                         if not matched:
                             self.log("Agent Pool not found")
                             to_be_updated = True
@@ -811,7 +955,17 @@ class AzureRMManagedCluster(AzureRMModuleBase):
         if self.agent_pool_profiles:
             agentpools = [self.create_agent_pool_profile_instance(profile) for profile in self.agent_pool_profiles]
 
-        service_principal_profile = self.create_service_principal_profile_instance(self.service_principal)
+        if self.service_principal:
+            service_principal_profile = self.create_service_principal_profile_instance(self.service_principal)
+            identity = None
+        else:
+            service_principal_profile = None
+            identity = self.managedcluster_models.ManagedClusterIdentity(type='SystemAssigned')
+
+        if self.linux_profile:
+            linux_profile = self.create_linux_profile_instance(self.linux_profile)
+        else:
+            linux_profile = None
 
         parameters = self.managedcluster_models.ManagedCluster(
             location=self.location,
@@ -820,10 +974,12 @@ class AzureRMManagedCluster(AzureRMModuleBase):
             tags=self.tags,
             service_principal_profile=service_principal_profile,
             agent_pool_profiles=agentpools,
-            linux_profile=self.create_linux_profile_instance(self.linux_profile),
+            linux_profile=linux_profile,
+            identity=identity,
             enable_rbac=self.enable_rbac,
             network_profile=self.create_network_profile_instance(self.network_profile),
             aad_profile=self.create_aad_profile_instance(self.aad_profile),
+            api_server_access_profile=self.create_api_server_access_profile_instance(self.api_server_access_profile),
             addon_profiles=self.create_addon_profile_instance(self.addon),
             node_resource_group=self.node_resource_group
         )
@@ -857,12 +1013,16 @@ class AzureRMManagedCluster(AzureRMModuleBase):
             if (profile['name'] in to_update_name_list):
                 self.log("Creating / Updating the AKS agentpool {0}".format(profile['name']))
                 parameters = self.managedcluster_models.AgentPool(
+                    count=profile["count"],
                     vm_size=profile["vm_size"],
+                    os_disk_size_gb=profile["os_disk_size_gb"],
                     max_count=profile["max_count"],
+                    node_labels=profile["node_labels"],
                     min_count=profile["min_count"],
                     max_pods=profile["max_pods"],
                     enable_auto_scaling=profile["enable_auto_scaling"],
-                    agent_pool_type=profile["type"]
+                    agent_pool_type=profile["type"],
+                    mode=profile["mode"]
                 )
                 try:
                     poller = self.managedcluster_client.agent_pools.create_or_update(self.resource_group, self.name, profile["name"], parameters)
@@ -970,6 +1130,9 @@ class AzureRMManagedCluster(AzureRMModuleBase):
     def create_network_profile_instance(self, network):
         return self.managedcluster_models.ContainerServiceNetworkProfile(**network) if network else None
 
+    def create_api_server_access_profile_instance(self, server_access):
+        return self.managedcluster_models.ManagedClusterAPIServerAccessProfile(**server_access) if server_access else None
+
     def create_aad_profile_instance(self, aad):
         return self.managedcluster_models.ManagedClusterAADProfile(**aad) if aad else None
 
