@@ -20,7 +20,7 @@ short_description: Manage Azure Public IP Addresses
 description:
     - Create, update and delete a Public IP address.
     - Allows setting and updating the address allocation method and domain name label.
-    - Use the M(azure_rm_networkinterface) module to associate a Public IP with a network interface.
+    - Use the M(azure.azcollection.azure_rm_networkinterface) module to associate a Public IP with a network interface.
 
 options:
     resource_group:
@@ -30,7 +30,7 @@ options:
     allocation_method:
         description:
             - Control whether the assigned Public IP remains permanently assigned to the object.
-            - If not set to C(Static), the IP address my changed anytime an associated virtual machine is power cycled.
+            - If not set to C(Static), the IP address may changed anytime an associated virtual machine is power cycled.
         choices:
             - dynamic
             - static
@@ -206,7 +206,7 @@ from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common
 from ansible.module_utils._text import to_native
 
 try:
-    from msrestazure.azure_exceptions import CloudError
+    from azure.core.exceptions import ResourceNotFoundError
 except ImportError:
     # This is handled in azure_rm_common
     pass
@@ -343,7 +343,7 @@ class AzureRMPublicIPAddress(AzureRMModuleBase):
             elif self.state == 'absent':
                 self.log("CHANGED: public ip {0} exists but requested state is 'absent'".format(self.name))
                 changed = True
-        except CloudError:
+        except ResourceNotFoundError:
             self.log('Public ip {0} does not exist'.format(self.name))
             if self.state == 'present':
                 self.log("CHANGED: pip {0} does not exist but requested state is 'present'".format(self.name))
@@ -379,6 +379,7 @@ class AzureRMPublicIPAddress(AzureRMModuleBase):
                     pip = self.network_models.PublicIPAddress(
                         location=results['location'],
                         public_ip_allocation_method=results['public_ip_allocation_method'],
+                        sku=self.network_models.PublicIPAddressSku(name=self.sku) if self.sku else None,
                         tags=results['tags']
                     )
                     if self.domain_name:
@@ -394,7 +395,7 @@ class AzureRMPublicIPAddress(AzureRMModuleBase):
 
     def create_or_update_pip(self, pip):
         try:
-            poller = self.network_client.public_ip_addresses.create_or_update(self.resource_group, self.name, pip)
+            poller = self.network_client.public_ip_addresses.begin_create_or_update(self.resource_group, self.name, pip)
             pip = self.get_poller_result(poller)
         except Exception as exc:
             self.fail("Error creating or updating {0} - {1}".format(self.name, str(exc)))
@@ -402,7 +403,7 @@ class AzureRMPublicIPAddress(AzureRMModuleBase):
 
     def delete_pip(self):
         try:
-            poller = self.network_client.public_ip_addresses.delete(self.resource_group, self.name)
+            poller = self.network_client.public_ip_addresses.begin_delete(self.resource_group, self.name)
             self.get_poller_result(poller)
         except Exception as exc:
             self.fail("Error deleting {0} - {1}".format(self.name, str(exc)))
