@@ -136,6 +136,12 @@ vms:
                     returned: always
                     type: str
                     sample: Standard_LRS
+                managed_disk_id:
+                    description:
+                        - Managed data disk ID.
+                    returned: always
+                    type: str
+                    sample: /subscriptions/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/resourceGroups/myResourceGroup/Microsoft.Compute/disks/diskName
         id:
             description:
                 - Resource ID.
@@ -198,6 +204,12 @@ vms:
             sample: [
                 "myNetworkInterface"
             ]
+        proximityPlacementGroup:
+            description:
+                - The name or ID of the proximity placement group the VM should be associated with.
+            type: dict
+            returned: always
+            sample: { "id": "/subscriptions/xxx/resourceGroups/xxx/providers/Microsoft.Compute/proximityPlacementGroups/testid13"}
         os_disk_caching:
             description:
                 - Type of OS disk caching.
@@ -245,11 +257,23 @@ vms:
             returned: always
             type: str
             sample: running
+        display_status:
+            description:
+                - The short localizable label for the status.
+            returned: always
+            type: str
+            sample: "VM running"
+        provisioning_state:
+            description:
+                - The provisioning state, which only appears in the response.
+            returned: always
+            type: str
+            sample: running
 '''
 
 try:
-    from msrestazure.azure_exceptions import CloudError
     from msrestazure.tools import parse_resource_id
+    from azure.core.exceptions import ResourceNotFoundError
 except Exception:
     # This is handled in azure_rm_common
     pass
@@ -284,6 +308,7 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
         self.tags = None
 
         super(AzureRMVirtualMachineInfo, self).__init__(self.module_arg_spec,
+                                                        supports_check_mode=True,
                                                         supports_tags=False,
                                                         facts_module=True)
 
@@ -322,7 +347,7 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
         self.log('List all items')
         try:
             items = self.compute_client.virtual_machines.list(self.resource_group)
-        except CloudError as exc:
+        except ResourceNotFoundError as exc:
             self.fail("Failed to list all items - {0}".format(str(exc)))
 
         results = []
@@ -335,7 +360,7 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
         self.log('List all items')
         try:
             items = self.compute_client.virtual_machines.list_all()
-        except CloudError as exc:
+        except ResourceNotFoundError as exc:
             self.fail("Failed to list all items - {0}".format(str(exc)))
 
         results = []
@@ -353,7 +378,7 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
         try:
             vm = self.compute_client.virtual_machines.get(resource_group, name, expand='instanceview')
             return self.serialize_vm(vm)
-        except Exception as exc:
+        except ResourceNotFoundError as exc:
             self.fail("Error getting virtual machine {0} - {1}".format(self.name, str(exc)))
 
     def serialize_vm(self, vm):
@@ -379,18 +404,27 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
             code = instance['statuses'][index]['code'].split('/')
             if code[0] == 'PowerState':
                 power_state = code[1]
+                display_status = instance['statuses'][index]['displayStatus']
             elif code[0] == 'OSState' and code[1] == 'generalized':
+                display_status = instance['statuses'][index]['displayStatus']
                 power_state = 'generalized'
                 break
+            elif code[0] == 'ProvisioningState' and code[1] == 'failed':
+                display_status = instance['statuses'][index]['displayStatus']
+                power_state = ''
+                break
 
         new_result = {}
         new_result['power_state'] = power_state
+        new_result['display_status'] = display_status
+        new_result['provisioning_state'] = vm.provisioning_state
         new_result['id'] = vm.id
         new_result['resource_group'] = resource_group
         new_result['name'] = vm.name
         new_result['state'] = 'present'
         new_result['location'] = vm.location
         new_result['vm_size'] = result['properties']['hardwareProfile']['vmSize']
+        new_result['proximityPlacementGroup'] = result['properties'].get('proximityPlacementGroup')
         new_result['zones'] = result.get('zones', None)
         os_profile = result['properties'].get('osProfile')
         if os_profile is not None:
@@ -438,6 +472,7 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
                 'name': disks[disk_index].get('name'),
                 'disk_size_gb': disks[disk_index].get('diskSizeGB'),
                 'managed_disk_type': disks[disk_index].get('managedDisk', {}).get('storageAccountType'),
+                'managed_disk_id': disks[disk_index].get('managedDisk', {}).get('id'),
                 'caching': disks[disk_index].get('caching')
             })
 
