@@ -51,7 +51,7 @@ class FactsBase(object):
 
 class Default(FactsBase):
 
-    COMMANDS = ["show version"]
+    COMMANDS = ["show version", "show virtual switch"]
 
     def populate(self):
         super(Default, self).populate()
@@ -61,6 +61,10 @@ class Default(FactsBase):
             self.facts["iostype"] = self.parse_iostype(data)
             self.facts["serialnum"] = self.parse_serialnum(data)
             self.parse_stacks(data)
+        data = self.responses[1]
+        vss_errs = ["Invalid input", "Switch Mode : Standalone"]
+        if data and not any(err in data for err in vss_errs):
+            self.parse_virtual_switch(data)
 
     def parse_iostype(self, data):
         match = re.search(r"\sIOS-XE\s", data)
@@ -85,6 +89,17 @@ class Default(FactsBase):
         if match:
             self.facts["stacked_serialnums"] = match
 
+        if "stacked_models" in self.facts:
+            self.facts["virtual_switch"] = "STACK"
+
+    def parse_virtual_switch(self, data):
+        match = re.search(
+            r"^Virtual switch domain number : ([0-9]+)", data, re.M
+        )
+        if match:
+            self.facts["virtual_switch"] = "VSS"
+            self.facts["virtual_switch_domain"] = match.group(1)
+
     def platform_facts(self):
         platform_facts = {}
 
@@ -366,7 +381,7 @@ class Interfaces(FactsBase):
             return match.group(1)
 
     def parse_lineprotocol(self, data):
-        match = re.search(r"line protocol is (\S+)\s*$", data, re.M)
+        match = re.search(r"line protocol is (\S+).+$", data, re.M)
         if match:
             return match.group(1)
 
