@@ -19,145 +19,118 @@ from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.n
 )
 
 
-def _tmplt_access_list_name(config_data):
-    try:
-        acl_id = int(config_data.get("name"))
-        if not config_data.get("acl_type"):
-            if acl_id >= 1 and acl_id <= 99:
-                config_data["acl_type"] = "standard"
-            if acl_id >= 100 and acl_id <= 199:
-                config_data["acl_type"] = "extended"
-    except ValueError:
-        pass
-    afi = config_data.get("afi")
-    if afi == "ipv4":
-        command = "ip access-list {acl_type} {name}".format(**config_data)
-    elif afi == "ipv6":
-        command = "ipv6 access-list {name}".format(**config_data)
-    return command
-
-
-def _tmplt_access_list_entries(config_data):
-    if "aces" in config_data:
-        command = []
-
-        def source_destination_common_config(config_data, command, attr):
-            if config_data[attr].get("address"):
-                command += " {address}".format(**config_data[attr])
-                if config_data[attr].get("wildcard_bits"):
-                    command += " {wildcard_bits}".format(**config_data[attr])
-            elif config_data[attr].get("any"):
-                command += " any".format(**config_data[attr])
-            elif config_data[attr].get("host"):
-                command += " host {host}".format(**config_data[attr])
-            elif config_data[attr].get("object_group"):
-                command += " object-group {object_group}".format(
-                    **config_data[attr]
+def _tmplt_access_list_entries(aces):
+    def source_destination_common_config(config_data, command, attr):
+        if config_data[attr].get("address"):
+            command += " {address}".format(**config_data[attr])
+            if config_data[attr].get("wildcard_bits"):
+                command += " {wildcard_bits}".format(**config_data[attr])
+        elif config_data[attr].get("any"):
+            command += " any".format(**config_data[attr])
+        elif config_data[attr].get("host"):
+            command += " host {host}".format(**config_data[attr])
+        elif config_data[attr].get("object_group"):
+            command += " object-group {object_group}".format(
+                **config_data[attr]
+            )
+        if config_data[attr].get("port_protocol"):
+            if config_data[attr].get("port_protocol").get("range"):
+                command += " range {0} {1}".format(
+                    config_data[attr]["port_protocol"]["range"].get("start"),
+                    config_data[attr]["port_protocol"]["range"].get("end"),
                 )
-            if config_data[attr].get("port_protocol"):
-                if config_data[attr].get("port_protocol").get("range"):
-                    command += " range {0} {1}".format(
-                        config_data[attr]["port_protocol"]["range"].get(
-                            "start"
-                        ),
-                        config_data[attr]["port_protocol"]["range"].get("end"),
-                    )
-                else:
-                    port_proto_type = list(
-                        config_data[attr]["port_protocol"].keys()
-                    )[0]
-                    command += " {0} {1}".format(
-                        port_proto_type,
-                        config_data[attr]["port_protocol"][port_proto_type],
-                    )
-            return command
-
-        command = ""
-        proto_option = None
-        if config_data.get("aces"):
-            aces = config_data["aces"]
-            if aces.get("sequence") and config_data.get("afi") == "ipv4":
-                command += "{sequence}".format(**aces)
-            if (
-                aces.get("grant")
-                and aces.get("sequence")
-                and config_data.get("afi") == "ipv4"
-            ):
-                command += " {grant}".format(**aces)
-            elif (
-                aces.get("grant")
-                and aces.get("sequence")
-                and config_data.get("afi") == "ipv6"
-            ):
-                command += "{grant}".format(**aces)
-            elif aces.get("grant"):
-                command += "{grant}".format(**aces)
-            if aces.get("protocol_options"):
-                if "protocol_number" in aces["protocol_options"]:
-                    command += " {protocol_number}".format(
-                        **aces["protocol_options"]
-                    )
-                else:
-                    command += " {0}".format(list(aces["protocol_options"])[0])
-                    proto_option = aces["protocol_options"].get(
-                        list(aces["protocol_options"])[0]
-                    )
-            elif aces.get("protocol"):
-                command += " {protocol}".format(**aces)
-            if aces.get("source"):
-                command = source_destination_common_config(
-                    aces, command, "source"
+            else:
+                port_proto_type = list(
+                    config_data[attr]["port_protocol"].keys()
+                )[0]
+                command += " {0} {1}".format(
+                    port_proto_type,
+                    config_data[attr]["port_protocol"][port_proto_type],
                 )
-            if aces.get("destination"):
-                command = source_destination_common_config(
-                    aces, command, "destination"
-                )
-            if proto_option:
-                command += " {0}".format(
-                    list(proto_option.keys())[0].replace("_", "-")
-                )
-            if aces.get("dscp"):
-                command += " dscp {dscp}".format(**aces)
-            if aces.get("sequence") and config_data.get("afi") == "ipv6":
-                command += " sequence {sequence}".format(**aces)
-            if aces.get("enable_fragments") or aces.get("fragments"):
-                command += " fragments"
-            if aces.get("log"):
-                command += " log"
-                if aces["log"].get("user_cookie"):
-                    command += " {user_cookie}".format(**aces["log"])
-            if aces.get("log_input"):
-                command += " log-input"
-                if aces["log_input"].get("user_cookie"):
-                    command += " {user_cookie}".format(**aces["log_input"])
-            if aces.get("option"):
-                option_val = list(aces.get("option").keys())[0]
-                command += " option {0}".format(option_val)
-            if aces.get("precedence"):
-                command += " precedence {precedence}".format(**aces)
-            if aces.get("time_range"):
-                command += " time-range {time_range}".format(**aces)
-            if aces.get("tos"):
-                command += " tos"
-                if aces["tos"].get("service_value"):
-                    command += " {service_value}".format(**aces["tos"])
-                elif aces["tos"].get("max_reliability"):
-                    command += " max-reliability"
-                elif aces["tos"].get("max_throughput"):
-                    command += " max-throughput"
-                elif aces["tos"].get("min_delay"):
-                    command += " min-delay"
-                elif aces["tos"].get("min_monetary_cost"):
-                    command += " min-monetary-cost"
-                elif aces["tos"].get("normal"):
-                    command += " normal"
-            if aces.get("ttl"):
-                command += " ttl {0}".format(list(aces["ttl"])[0])
-                proto_option = aces["ttl"].get(list(aces["ttl"])[0])
-                command += " {0}".format(proto_option)
-            return command
         return command
 
+    command = ""
+    proto_option = None
+    if aces:
+        if aces.get("sequence") and aces.get("afi") == "ipv4":
+            command += "{sequence}".format(**aces)
+        if (
+            aces.get("grant")
+            and aces.get("sequence")
+            and aces.get("afi") == "ipv4"
+        ):
+            command += " {grant}".format(**aces)
+        elif (
+            aces.get("grant")
+            and aces.get("sequence")
+            and aces.get("afi") == "ipv6"
+        ):
+            command += "{grant}".format(**aces)
+        elif aces.get("grant"):
+            command += "{grant}".format(**aces)
+        if aces.get("protocol_options"):
+            if "protocol_number" in aces["protocol_options"]:
+                command += " {protocol_number}".format(
+                    **aces["protocol_options"]
+                )
+            else:
+                command += " {0}".format(list(aces["protocol_options"])[0])
+                proto_option = aces["protocol_options"].get(
+                    list(aces["protocol_options"])[0]
+                )
+        elif aces.get("protocol"):
+            command += " {protocol}".format(**aces)
+        if aces.get("source"):
+            command = source_destination_common_config(aces, command, "source")
+        if aces.get("destination"):
+            command = source_destination_common_config(
+                aces, command, "destination"
+            )
+        if proto_option:
+            command += " {0}".format(
+                list(proto_option.keys())[0].replace("_", "-")
+            )
+        if aces.get("dscp"):
+            command += " dscp {dscp}".format(**aces)
+        if aces.get("sequence") and aces.get("afi") == "ipv6":
+            command += " sequence {sequence}".format(**aces)
+        if aces.get("enable_fragments") or aces.get("fragments"):
+            command += " fragments"
+        if aces.get("log"):
+            command += " log"
+            if aces["log"].get("user_cookie"):
+                command += " {user_cookie}".format(**aces["log"])
+        if aces.get("log_input"):
+            command += " log-input"
+            if aces["log_input"].get("user_cookie"):
+                command += " {user_cookie}".format(**aces["log_input"])
+        if aces.get("option"):
+            option_val = list(aces.get("option").keys())[0]
+            command += " option {0}".format(option_val)
+        if aces.get("precedence"):
+            command += " precedence {precedence}".format(**aces)
+        if aces.get("time_range"):
+            command += " time-range {time_range}".format(**aces)
+        if aces.get("tos"):
+            command += " tos"
+            if aces["tos"].get("service_value"):
+                command += " {service_value}".format(**aces["tos"])
+            elif aces["tos"].get("max_reliability"):
+                command += " max-reliability"
+            elif aces["tos"].get("max_throughput"):
+                command += " max-throughput"
+            elif aces["tos"].get("min_delay"):
+                command += " min-delay"
+            elif aces["tos"].get("min_monetary_cost"):
+                command += " min-monetary-cost"
+            elif aces["tos"].get("normal"):
+                command += " normal"
+        if aces.get("ttl"):
+            command += " ttl {0}".format(list(aces["ttl"])[0])
+            proto_option = aces["ttl"].get(list(aces["ttl"])[0])
+            command += " {0}".format(proto_option)
+    return command
+
 
 class AclsTemplate(NetworkTemplate):
     def __init__(self, lines=None):
@@ -167,7 +140,7 @@ class AclsTemplate(NetworkTemplate):
         {
             "name": "acls_name",
             "getval": re.compile(
-                r"""^(?P<acl_type>Standard|Extended)*
+                r"""^(?P<acl_type>Standard|Extended|Reflexive)*
                     \s*(?P<afi>IP|IPv6)*
                     \s*access*
                     \s*list*
@@ -176,7 +149,7 @@ class AclsTemplate(NetworkTemplate):
                 re.VERBOSE,
             ),
             "compval": "name",
-            "setval": _tmplt_access_list_name,
+            "setval": "name",
             "result": {
                 "acls": {
                     "{{ acl_name|d() }}": {
@@ -216,7 +189,7 @@ class AclsTemplate(NetworkTemplate):
                 "acls": {
                     "{{ acl_name_r|d() }}": {
                         "name": "{{ acl_name_r }}",
-                        "aces": [{"remarks": ["{{ remarks }}"]}],
+                        "aces": [{"remarks": "{{ remarks }}"}],
                     }
                 }
             },
@@ -235,7 +208,7 @@ class AclsTemplate(NetworkTemplate):
                 "acls": {
                     "{{ acl_name_linear|d() }}": {
                         "name": "{{ acl_name_linear }}",
-                        "aces": [{"remarks": ["{{ remarks }}"]}],
+                        "aces": [{"remarks": "{{ remarks }}"}],
                     }
                 }
             },
@@ -247,8 +220,8 @@ class AclsTemplate(NetworkTemplate):
                         \s(?P<grant>deny|permit)?
                         (\s+(?P<address>(?!ahp|eigrp|esp|gre|icmp|igmp|ipv6|ipinip|ip|nos|object-group|ospf|pcp|pim|sctp|tcp|udp)\S+|\S+,))?
                         (\s*(?P<any>any))?
-                        (\shost\s(?P<host>\S+))?
                         (\swildcard\sbits\s(?P<wildcard>\S+))?
+                        (\shost\s(?P<host>\S+))?
                         (\s(?P<log>log))?
                     $""",
                 re.VERBOSE,
