@@ -428,8 +428,10 @@ def _tmplt_ospf_mpls_traffic_eng(config_data):
                 **config_data["mpls"]["traffic_eng"]
             )
         elif "autoroute_exclude" in config_data["mpls"]["traffic_eng"]:
-            command += " autoroute-exclude prefix-list {autoroute_exclude}".format(
-                **config_data["mpls"]["traffic_eng"]
+            command += (
+                " autoroute-exclude prefix-list {autoroute_exclude}".format(
+                    **config_data["mpls"]["traffic_eng"]
+                )
             )
         elif "interface" in config_data["mpls"]["traffic_eng"]:
             command += " interface {int_type}".format(
@@ -476,13 +478,14 @@ def _tmplt_ospf_neighbor(config_data):
 
 def _tmplt_ospf_network(config_data):
     if "network" in config_data:
-        command = "network"
-        if "address" in config_data["network"]:
-            command += " {address} {wildcard_bits}".format(
-                **config_data["network"]
-            )
-        if "area" in config_data["network"]:
-            command += " area {area}".format(**config_data["network"])
+        command = []
+        for each in config_data["network"]:
+            cmd = "network"
+            if "address" in each:
+                cmd += " {address} {wildcard_bits}".format(**each)
+            if "area" in each:
+                cmd += " area {area}".format(**each)
+            command.append(cmd)
         return command
 
 
@@ -528,6 +531,20 @@ def _tmplt_ospf_queue_depth_update(config_data):
         return command
 
 
+def _tmplt_ospf_passive_interfaces(config_data):
+    if "passive_interfaces" in config_data:
+        if config_data["passive_interfaces"].get("default"):
+            cmd = "passive-interface default"
+        if config_data["passive_interfaces"].get("interface"):
+            if config_data["passive_interfaces"].get("set_interface"):
+                for each in config_data["passive_interfaces"]["interface"]:
+                    cmd = "passive-interface {0}".format(each)
+            elif not config_data["passive_interfaces"].get("set_interface"):
+                for each in config_data["passive_interfaces"]["interface"]:
+                    cmd = "no passive-interface {0}".format(each)
+        return cmd
+
+
 def _tmplt_ospf_summary_address(config_data):
     if "summary_address" in config_data:
         command = "summary-address {address} {mask}".format(
@@ -1591,11 +1608,13 @@ class Ospfv2Template(NetworkTemplate):
             "result": {
                 "processes": {
                     "{{ pid }}": {
-                        "network": {
-                            "address": "{{ address }}",
-                            "wildcard_bits": "{{ wildcard }}",
-                            "area": "{{ area.split(" ")[1] }}",
-                        }
+                        "network": [
+                            {
+                                "address": "{{ address }}",
+                                "wildcard_bits": "{{ wildcard }}",
+                                "area": "{{ area.split(" ")[1] }}",
+                            }
+                        ]
                     }
                 }
             },
@@ -1652,6 +1671,32 @@ class Ospfv2Template(NetworkTemplate):
                 }
             },
         },
+        {
+            "name": "passive_interfaces",
+            "getval": re.compile(
+                r"""\s*(?P<no>no)*
+                    \s*passive-interface*
+                    \s*(?P<interface>\S+\s\S+|\S+)
+                    *$""",
+                re.VERBOSE,
+            ),
+            "setval": _tmplt_ospf_passive_interfaces,
+            "result": {
+                "processes": {
+                    "{{ pid }}": {
+                        "passive_interfaces": {
+                            "default": "{{ True if 'default' in interface }}",
+                            "interface": {
+                                "set_interface": "{% if no is defined %}{{ False }}{% elif 'default' not in interface %}{{ True }}{% endif %}",
+                                "name": [
+                                    "{{ interface if 'default' not in interface }}"
+                                ],
+                            },
+                        }
+                    }
+                }
+            },
+        },
         {
             "name": "passive_interface",
             "getval": re.compile(
