@@ -34,7 +34,7 @@ def add_command_to_config_list(interface, cmd, commands):
 
 
 def reverify_diff_py35(want, have):
-    """ Function to re-verify the set diff for py35 as it doesn't maintains dict order which results
+    """Function to re-verify the set diff for py35 as it doesn't maintains dict order which results
         into unexpected set diff
     :param config: want and have set config
     :returns: True/False post checking if there's any actual diff b/w want and have sets
@@ -292,8 +292,7 @@ def is_valid_ip(ip_str):
 
 
 def normalize_interface(name):
-    """Return the normalized interface name
-    """
+    """Return the normalized interface name"""
     if not name:
         return
 
@@ -306,6 +305,8 @@ def normalize_interface(name):
 
     if name.lower().startswith("gi"):
         if_type = "GigabitEthernet"
+    elif name.lower().startswith("twe"):
+        if_type = "TwentyFiveGigE"
     elif name.lower().startswith("tw"):
         if_type = "TwoGigabitEthernet"
     elif name.lower().startswith("te"):
@@ -314,6 +315,8 @@ def normalize_interface(name):
         if_type = "FastEthernet"
     elif name.lower().startswith("fo"):
         if_type = "FortyGigabitEthernet"
+    elif name.lower().startswith("fi"):
+        if_type = "FiveGigabitEthernet"
     elif name.lower().startswith("long"):
         if_type = "LongReachEthernet"
     elif name.lower().startswith("et"):
@@ -326,14 +329,14 @@ def normalize_interface(name):
         if_type = "Port-channel"
     elif name.lower().startswith("nv"):
         if_type = "nve"
-    elif name.lower().startswith("twe"):
-        if_type = "TwentyFiveGigE"
     elif name.lower().startswith("hu"):
         if_type = "HundredGigE"
     elif name.lower().startswith("virtual-te"):
         if_type = "Virtual-Template"
     elif name.lower().startswith("tu"):
         if_type = "Tunnel"
+    elif name.lower().startswith("se"):
+        if_type = "Serial"
     else:
         if_type = None
 
@@ -352,8 +355,7 @@ def normalize_interface(name):
 
 
 def get_interface_type(interface):
-    """Gets the type of interface
-    """
+    """Gets the type of interface"""
 
     if interface.upper().startswith("GI"):
         return "GigabitEthernet"
@@ -365,6 +367,8 @@ def get_interface_type(interface):
         return "FastEthernet"
     elif interface.upper().startswith("FO"):
         return "FortyGigabitEthernet"
+    elif interface.upper().startswith("FI"):
+        return "FiveGigabitEthernet"
     elif interface.upper().startswith("LON"):
         return "LongReachEthernet"
     elif interface.upper().startswith("ET"):
@@ -385,5 +389,7 @@ def get_interface_type(interface):
         return "Virtual-Template"
     elif interface.upper().startswith("TU"):
         return "Tunnel"
+    elif interface.upper().startswith("SE"):
+        return "Serial"
     else:
         return "unknown"
