@@ -23,13 +23,15 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 DOCUMENTATION = """
 module: ios_acl_interfaces
-short_description: ACL interfaces resource module
+short_description: Resource module to configure ACL interfaces.
 description: This module configures and manages the access-control (ACL) attributes
   of interfaces on IOS platforms.
 version_added: 1.0.0
 author: Sumit Jaiswal (@justjais)
 notes:
-- Tested against Cisco IOSv Version 15.2 on VIRL
+  - Tested against Cisco IOSv Version 15.2 on VIRL
+  - This module works with connection C(network_cli).
+    See U(https://docs.ansible.com/ansible/latest/network/user_guide/platform_ios.html)
 options:
   config:
     description: A dictionary of ACL interfaces options
