@@ -14,7 +14,7 @@ __metaclass__ = type
 
 DOCUMENTATION = """
 module: ios_route_maps
-short_description: Route maps resource module
+short_description: Resource module to configure route maps.
 description:
   - This module configures and manages the attributes of Route maps on Cisco IOS.
 version_added: 2.1.0
@@ -22,7 +22,7 @@ author: Sumit Jaiswal (@justjais)
 notes:
   - Tested against Cisco IOSv Version 15.2 on VIRL
   - This module works with connection C(network_cli).
-    See L(IOS Platform Options,../network/user_guide/platform_ios.html)
+    See U(https://docs.ansible.com/ansible/latest/network/user_guide/platform_ios.html)
 options:
   config:
     description: A list of configurations for Route maps.
