@@ -31,7 +31,7 @@ deprecated:
   why: Newer and updated modules released with more functionality in Ansible 2.9
   removed_at_date: '2022-06-01'
 notes:
-- Tested against IOS 15.2
+  - Tested against IOS 15.2
 options:
   name:
     description:
@@ -365,8 +365,7 @@ def check_declarative_intent_params(want, module, result):
 
 
 def main():
-    """ main entry point for module execution
-    """
+    """main entry point for module execution"""
     element_spec = dict(
         vlan_id=dict(type="int"),
         name=dict(),
