@@ -51,7 +51,7 @@ class Vlans(ConfigBase):
         return self.facts.get("ansible_net_platform", "")
 
     def get_vlans_facts(self, data=None):
-        """ Get the 'facts' (the current configuration)
+        """Get the 'facts' (the current configuration)
 
         :rtype: A dictionary
         :returns: The current configuration as a dictionary
@@ -72,7 +72,7 @@ class Vlans(ConfigBase):
         return self._connection.edit_config(commands)
 
     def execute_module(self):
-        """ Execute the module
+        """Execute the module
 
         :rtype: A dictionary
         :returns: The result from module execution
@@ -125,7 +125,7 @@ class Vlans(ConfigBase):
         return result
 
     def set_config(self, existing_vlans_facts):
-        """ Collect the configuration from the args passed to the module,
+        """Collect the configuration from the args passed to the module,
             collect the current configuration (as a dict from facts)
 
         :rtype: A list
@@ -138,7 +138,7 @@ class Vlans(ConfigBase):
         return to_list(resp)
 
     def set_state(self, want, have):
-        """ Select the appropriate function based on the state provided
+        """Select the appropriate function based on the state provided
 
         :param want: the desired configuration as a dictionary
         :param have: the current configuration as a dictionary
@@ -172,8 +172,7 @@ class Vlans(ConfigBase):
         return commands
 
     def remove_default_states(self, obj):
-        """Removes non-empty but default states from the obj.
-        """
+        """Removes non-empty but default states from the obj."""
         default_states = {"enabled": True, "state": "active", "mode": "ce"}
         for k in default_states.keys():
             if obj.get(k) == default_states[k]:
@@ -181,7 +180,7 @@ class Vlans(ConfigBase):
         return obj
 
     def _state_replaced(self, want, have):
-        """ The command generator when state is replaced.
+        """The command generator when state is replaced.
         Scope is limited to vlan objects defined in the playbook.
         :rtype: A list
         :returns: The minimum command set required to migrate the current
@@ -215,7 +214,7 @@ class Vlans(ConfigBase):
         return cmds
 
     def _state_overridden(self, want, have):
-        """ The command generator when state is overridden.
+        """The command generator when state is overridden.
         Scope includes all vlan objects on the device.
         :rtype: A list
         :returns: the minimum command set required to migrate the current
@@ -243,7 +242,7 @@ class Vlans(ConfigBase):
         return cmds
 
     def _state_merged(self, w, have):
-        """ The command generator when state is merged
+        """The command generator when state is merged
 
         :rtype: A list
         :returns: the commands necessary to merge the provided into
@@ -255,7 +254,7 @@ class Vlans(ConfigBase):
         return cmds
 
     def _state_deleted(self, want, have):
-        """ The command generator when state is deleted
+        """The command generator when state is deleted
 
         :rtype: A list
         :returns: the commands necessary to remove the current configuration
@@ -275,8 +274,7 @@ class Vlans(ConfigBase):
         return commands
 
     def del_attribs(self, obj):
-        """Returns a list of commands to reset states to default
-        """
+        """Returns a list of commands to reset states to default"""
         commands = []
         if not obj:
             return commands
