@@ -20,6 +20,7 @@ description:
 version_added: 2.0.0
 notes:
 - Tested against NX-OS 9.3.6.
+- Unsupported for Cisco MDS
 - For managing BGP address family configurations please use
   the M(cisco.nxos.nxos_bgp_address_family) module.
 - This module works with connection C(network_cli) and C(httpapi).
@@ -270,7 +271,7 @@ EXAMPLES = """
 # Nexus9000v# show running-config | section "^router bgp"
 # Nexus9000v#
 
-- name: Merge the provided configuration with the exisiting running configuration
+- name: Merge the provided configuration with the existing running configuration
   cisco.nxos.nxos_bgp_neighbor_address_family: &id001
     config:
       as_number: 65536
@@ -608,7 +609,7 @@ EXAMPLES = """
 #       address-family ipv6 unicast
 #
 
-- name: Overridde all BGP AF configuration with provided configuration
+- name: Override all BGP AF configuration with provided configuration
   cisco.nxos.nxos_bgp_neighbor_address_family:
     config:
       as_number: 65536
