@@ -26,6 +26,7 @@ author:
 - Trishna Guha (@trishnaguha)
 notes:
 - Tested against NXOSv 7.0(3)I5(1).
+- Unsupported for Cisco MDS
 options:
   name:
     description:
@@ -333,8 +334,7 @@ def remove_switchport_config_commands(name, existing, proposed, module):
 
 
 def get_switchport_config_commands(name, existing, proposed, module):
-    """Gets commands required to config a given switchport interface
-    """
+    """Gets commands required to config a given switchport interface"""
 
     proposed_mode = proposed.get("mode")
     existing_mode = existing.get("mode")
@@ -463,8 +463,7 @@ def get_list_of_vlans(module):
 
 
 def numerical_sort(string_int_list):
-    """Sorts list of strings/integers that are digits in numerical order.
-    """
+    """Sorts list of strings/integers that are digits in numerical order."""
 
     as_int_list = []
     as_str_list = []
@@ -529,8 +528,7 @@ def map_params_to_obj(module):
 
 
 def main():
-    """ main entry point for module execution
-    """
+    """main entry point for module execution"""
     element_spec = dict(
         name=dict(type="str", aliases=["interface"]),
         mode=dict(choices=["access", "trunk"]),
