@@ -18,7 +18,6 @@
 # Make coding more python3-ish
 
 from __future__ import absolute_import, division, print_function
-from typing import Sequence
 
 __metaclass__ = type
 
@@ -385,13 +384,11 @@ class TestNxosNtpGlobalModule(TestNxosModule):
                             key_id=2,
                             minpoll=5,
                             maxpoll=15,
-                            use_vrf="siteA",
+                            vrf="siteA",
                             prefer=True,
                         ),
-                        dict(peer="192.168.1.2", key_id=3, use_vrf="siteB"),
-                        dict(
-                            peer="192.168.1.3", maxpoll=10, use_vrf="default"
-                        ),
+                        dict(peer="192.168.1.2", key_id=3, vrf="siteB"),
+                        dict(peer="192.168.1.3", maxpoll=10, vrf="default"),
                     ],
                     servers=[
                         dict(
@@ -399,13 +396,11 @@ class TestNxosNtpGlobalModule(TestNxosModule):
                             key_id=2,
                             minpoll=5,
                             maxpoll=15,
-                            use_vrf="siteA",
+                            vrf="siteA",
                             prefer=True,
                         ),
-                        dict(server="203.0.113.2", key_id=3, use_vrf="siteB"),
-                        dict(
-                            server="203.0.113.3", maxpoll=10, use_vrf="default"
-                        ),
+                        dict(server="203.0.113.2", key_id=3, vrf="siteB"),
+                        dict(server="203.0.113.3", maxpoll=10, vrf="default"),
                     ],
                 ),
                 state="merged",
@@ -436,10 +431,10 @@ class TestNxosNtpGlobalModule(TestNxosModule):
                             key_id=2,
                             minpoll=5,
                             maxpoll=15,
-                            use_vrf="siteA",
+                            vrf="siteA",
                             prefer=True,
                         ),
-                        dict(peer="192.168.1.2", use_vrf="siteB"),
+                        dict(peer="192.168.1.2", vrf="siteB"),
                     ],
                     servers=[
                         dict(
@@ -447,7 +442,7 @@ class TestNxosNtpGlobalModule(TestNxosModule):
                             key_id=2,
                             minpoll=5,
                             maxpoll=15,
-                            use_vrf="siteA",
+                            vrf="siteA",
                             prefer=True,
                         )
                     ],
@@ -480,7 +475,7 @@ class TestNxosNtpGlobalModule(TestNxosModule):
                         dict(key_id=1002),
                         dict(key_id=1003),
                     ],
-                    source_interface="192.168.1.100",
+                    source_interface="Ethernet1/1",
                 ),
                 state="merged",
             ),
@@ -490,7 +485,7 @@ class TestNxosNtpGlobalModule(TestNxosModule):
             "ntp trusted-key 1001",
             "ntp trusted-key 1002",
             "ntp trusted-key 1003",
-            "ntp source-interface 192.168.1.100",
+            "ntp source-interface Ethernet1/1",
         ]
         result = self.execute_module(changed=True)
         self.assertEqual(set(result["commands"]), set(commands))
@@ -502,7 +497,7 @@ class TestNxosNtpGlobalModule(TestNxosModule):
             ntp trusted-key 1001
             ntp trusted-key 1002
             ntp trusted-key 1003
-            ntp source-interface 192.168.1.100
+            ntp source-interface  Ethernet1/1
             """
         )
         set_module_args(
@@ -513,7 +508,7 @@ class TestNxosNtpGlobalModule(TestNxosModule):
                         dict(key_id=1002),
                         dict(key_id=1003),
                     ],
-                    source_interface="192.168.1.100",
+                    source_interface="Ethernet1/1",
                 ),
                 state="merged",
             ),
@@ -522,6 +517,23 @@ class TestNxosNtpGlobalModule(TestNxosModule):
         result = self.execute_module(changed=False)
         self.assertEqual(result["commands"], [])
 
+    def test_nxos_ntp_global_source_interface_merged_idempotent(self):
+        # test merged for complex attributes - 3 (idempotent)
+        self.get_config.return_value = dedent(
+            """\
+            ntp trusted-key 1001
+            ntp trusted-key 1002
+            ntp trusted-key 1003
+            ntp source-interface Ethernet1/1
+            """
+        )
+        set_module_args(
+            dict(config=dict(source_interface="Ethernet1/1"), state="merged"),
+            ignore_provider_arg,
+        )
+        result = self.execute_module(changed=False)
+        self.assertEqual(result["commands"], [])
+
     def test_nxos_ntp_global_complex_3_replaced(self):
         # test replaced for complex attributes - 3
         self.get_config.return_value = dedent(
