@@ -58,7 +58,7 @@ options:
     vars:
     - name: ansible_aws_ssm_profile
     version_added: 1.5.0
-  retries:
+  reconnection_retries:
     description: Number of attempts to connect.
     default: 3
     type: integer
@@ -70,6 +70,18 @@ options:
     type: integer
     vars:
     - name: ansible_aws_ssm_timeout
+  bucket_sse_mode:
+    description: Server-side encryption mode to use for uploads on the S3 bucket used for file transfer.
+    choices: [ 'AES256', 'aws:kms' ]
+    required: false
+    version_added: 2.2.0
+    vars:
+    - name: ansible_aws_ssm_bucket_sse_mode
+  bucket_sse_kms_key_id:
+    description: KMS key id to use when encrypting objects using C(bucket_sse_mode=aws:kms). Ignored otherwise.
+    version_added: 2.2.0
+    vars:
+    - name: ansible_aws_ssm_bucket_sse_kms_key_id
 '''
 
 EXAMPLES = r'''
@@ -162,6 +174,20 @@ EXAMPLES = r'''
         state: directory
 # Execution:  ansible-playbook win_file.yaml -i aws_ec2.yml
 # The playbook tasks will get executed on the instance ids returned from the dynamic inventory plugin using ssm connection.
+
+# Install a Nginx Package on Linux Instance; with specific SSE for file transfer
+- name: Install a Nginx Package
+  vars:
+    ansible_connection: aws_ssm
+    ansible_aws_ssm_bucket_name: nameofthebucket
+    ansible_aws_ssm_region: us-west-2
+    ansible_aws_ssm_bucket_sse_mode: 'aws:kms'
+    ansible_aws_ssm_bucket_sse_kms_key_id: alias/kms-key-alias
+  tasks:
+    - name: Install a Nginx Package
+      yum:
+        name: nginx
+        state: present
 '''
 
 import os
@@ -206,7 +232,7 @@ def _ssm_retry(func):
     """
     @wraps(func)
     def wrapped(self, *args, **kwargs):
-        remaining_tries = int(self.get_option('retries')) + 1
+        remaining_tries = int(self.get_option('reconnection_retries')) + 1
         cmd_summary = "%s..." % args[0]
         for attempt in range(remaining_tries):
             cmd = args[0]
@@ -506,11 +532,14 @@ class Connection(ConnectionBase):
 
         return stderr
 
-    def _get_url(self, client_method, bucket_name, out_path, http_method, profile_name):
+    def _get_url(self, client_method, bucket_name, out_path, http_method, profile_name, extra_args=None):
         ''' Generate URL for get_object / put_object '''
         region_name = self.get_option('region') or 'us-east-1'
         client = self._get_boto_client('s3', region_name=region_name, profile_name=profile_name)
-        return client.generate_presigned_url(client_method, Params={'Bucket': bucket_name, 'Key': out_path}, ExpiresIn=3600, HttpMethod=http_method)
+        params = {'Bucket': bucket_name, 'Key': out_path}
+        if extra_args is not None:
+            params.update(extra_args)
+        return client.generate_presigned_url(client_method, Params=params, ExpiresIn=3600, HttpMethod=http_method)
 
     def _get_boto_client(self, service, region_name=None, profile_name=None):
         ''' Gets a boto3 client based on the STS token '''
@@ -554,14 +583,29 @@ class Connection(ConnectionBase):
 
         profile_name = self.get_option('profile')
 
+        put_args = dict()
+        put_headers = dict()
+        if self.get_option('bucket_sse_mode'):
+            put_args['ServerSideEncryption'] = self.get_option('bucket_sse_mode')
+            put_headers['x-amz-server-side-encryption'] = self.get_option('bucket_sse_mode')
+            if self.get_option('bucket_sse_mode') == 'aws:kms' and self.get_option('bucket_sse_kms_key_id'):
+                put_args['SSEKMSKeyId'] = self.get_option('bucket_sse_kms_key_id')
+                put_headers['x-amz-server-side-encryption-aws-kms-key-id'] = self.get_option('bucket_sse_kms_key_id')
+
         if self.is_windows:
-            put_command = "Invoke-WebRequest -Method PUT -InFile '%s' -Uri '%s' -UseBasicParsing" % (
-                in_path, self._get_url('put_object', self.get_option('bucket_name'), s3_path, 'PUT', profile_name))
+            put_command_headers = "; ".join(["'%s' = '%s'" % (h, v) for h, v in put_headers.items()])
+            put_command = "Invoke-WebRequest -Method PUT -Headers @{%s} -InFile '%s' -Uri '%s' -UseBasicParsing" % (
+                put_command_headers, in_path,
+                self._get_url('put_object', self.get_option('bucket_name'), s3_path, 'PUT', profile_name,
+                              extra_args=put_args))
             get_command = "Invoke-WebRequest '%s' -OutFile '%s'" % (
                 self._get_url('get_object', self.get_option('bucket_name'), s3_path, 'GET', profile_name), out_path)
         else:
-            put_command = "curl --request PUT --upload-file '%s' '%s'" % (
-                in_path, self._get_url('put_object', self.get_option('bucket_name'), s3_path, 'PUT', profile_name))
+            put_command_headers = "".join(["-H '%s: %s' " % (h, v) for h, v in put_headers.items()])
+            put_command = "curl --request PUT %s--upload-file '%s' '%s'" % (
+                put_command_headers, in_path,
+                self._get_url('put_object', self.get_option('bucket_name'), s3_path, 'PUT', profile_name,
+                              extra_args=put_args))
             get_command = "curl '%s' -o '%s'" % (
                 self._get_url('get_object', self.get_option('bucket_name'), s3_path, 'GET', profile_name), out_path)
 
@@ -572,7 +616,7 @@ class Connection(ConnectionBase):
                 client.download_fileobj(self.get_option('bucket_name'), s3_path, data)
         else:
             with open(to_bytes(in_path, errors='surrogate_or_strict'), 'rb') as data:
-                client.upload_fileobj(data, self.get_option('bucket_name'), s3_path)
+                client.upload_fileobj(data, self.get_option('bucket_name'), s3_path, ExtraArgs=put_args)
             (returncode, stdout, stderr) = self.exec_command(get_command, in_data=None, sudoable=False)
 
         # Remove the files from the bucket after they've been transferred
