@@ -15,7 +15,6 @@ description:
     - Manage an AWS Elastic Load Balancer target group. See
       U(https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-target-groups.html) or
       U(https://docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-target-groups.html) for details.
-requirements: [ boto3 ]
 author: "Rob White (@wimnat)"
 options:
   deregistration_delay_timeout:
@@ -102,9 +101,22 @@ options:
       - The time period, in seconds, during which requests from a client should be routed to the same target. After this time period expires, the load
         balancer-generated cookie is considered stale. The range is 1 second to 1 week (604800 seconds).
     type: int
+  stickiness_app_cookie_duration:
+    description:
+      - The time period, in seconds, during which requests from a client
+        should be routed to the same target. After this time period expires,
+        the application-generated cookie is considered stale. The range is 1 second to 1 week (604800 seconds).
+    type: int
+    version_added: 1.5.0
+  stickiness_app_cookie_name:
+    description:
+      - The name of the application cookie. Required if I(stickiness_type=app_cookie).
+    type: str
+    version_added: 1.5.0
   stickiness_type:
     description:
       - The type of sticky sessions.
+      - Valid values are C(lb_cookie), C(app_cookie) or C(source_ip).
       - If not set AWS will default to C(lb_cookie) for Application Load Balancers or C(source_ip) for Network Load Balancers.
     type: str
   successful_response_codes:
@@ -149,6 +161,23 @@ options:
       - The identifier of the virtual private cloud (VPC). Required when I(state) is C(present).
     required: false
     type: str
+  preserve_client_ip_enabled:
+    description:
+      - Indicates whether client IP preservation is enabled.
+      - The default is disabled if the target group type is C(ip) address and the target group protocol is C(tcp) or C(tls).
+        Otherwise, the default is enabled. Client IP preservation cannot be disabled for C(udp) and C(tcp_udp) target groups.
+      - I(preserve_client_ip_enabled) is supported only by Network Load Balancers.
+    type: bool
+    required: false
+    version_added: 2.1.0
+  proxy_protocol_v2_enabled:
+    description:
+      - Indicates whether Proxy Protocol version 2 is enabled.
+      - The value is C(true) or C(false).
+      - I(proxy_protocol_v2_enabled) is supported only by Network Load Balancers.
+    type: bool
+    required: false
+    version_added: 2.1.0
   wait:
     description:
       - Whether or not to wait for the target group.
@@ -442,12 +471,6 @@ def wait_for_status(connection, module, target_group_arn, targets, status):
     return status_achieved, result
 
 
-def fail_if_ip_target_type_not_supported(module):
-    if not module.botocore_at_least('1.7.2'):
-        module.fail_json(msg="target_type ip requires botocore version 1.7.2 or later. Version %s is installed" %
-                         botocore.__version__)
-
-
 def create_or_update_target_group(connection, module):
 
     changed = False
@@ -466,12 +489,16 @@ def create_or_update_target_group(connection, module):
     stickiness_enabled = module.params.get("stickiness_enabled")
     stickiness_lb_cookie_duration = module.params.get("stickiness_lb_cookie_duration")
     stickiness_type = module.params.get("stickiness_type")
+    stickiness_app_cookie_duration = module.params.get("stickiness_app_cookie_duration")
+    stickiness_app_cookie_name = module.params.get("stickiness_app_cookie_name")
+    preserve_client_ip_enabled = module.params.get("preserve_client_ip_enabled")
+    proxy_protocol_v2_enabled = module.params.get("proxy_protocol_v2_enabled")
 
     health_option_keys = [
         "health_check_path", "health_check_protocol", "health_check_interval", "health_check_timeout",
         "healthy_threshold_count", "unhealthy_threshold_count", "successful_response_codes"
     ]
-    health_options = any([module.params[health_option_key] is not None for health_option_key in health_option_keys])
+    health_options = any(module.params[health_option_key] is not None for health_option_key in health_option_keys)
 
     # Set health check if anything set
     if health_options:
@@ -505,10 +532,6 @@ def create_or_update_target_group(connection, module):
                 params['Matcher'] = {}
                 params['Matcher']['HttpCode'] = module.params.get("successful_response_codes")
 
-    # Get target type
-    if target_type == 'ip':
-        fail_if_ip_target_type_not_supported(module)
-
     # Get target group
     tg = get_target_group(connection, module)
 
@@ -753,6 +776,19 @@ def create_or_update_target_group(connection, module):
     if stickiness_type is not None:
         if stickiness_type != current_tg_attributes.get('stickiness_type'):
             update_attributes.append({'Key': 'stickiness.type', 'Value': stickiness_type})
+    if stickiness_app_cookie_name is not None:
+        if stickiness_app_cookie_name != current_tg_attributes.get('stickiness_app_cookie_name'):
+            update_attributes.append({'Key': 'stickiness.app_cookie.cookie_name', 'Value': str(stickiness_app_cookie_name)})
+    if stickiness_app_cookie_duration is not None:
+        if str(stickiness_app_cookie_duration) != current_tg_attributes['stickiness_app_cookie_duration_seconds']:
+            update_attributes.append({'Key': 'stickiness.app_cookie.duration_seconds', 'Value': str(stickiness_app_cookie_duration)})
+    if preserve_client_ip_enabled is not None:
+        if target_type not in ('udp', 'tcp_udp'):
+            if str(preserve_client_ip_enabled).lower() != current_tg_attributes.get('preserve_client_ip_enabled'):
+                update_attributes.append({'Key': 'preserve_client_ip.enabled', 'Value': str(preserve_client_ip_enabled).lower()})
+    if proxy_protocol_v2_enabled is not None:
+        if str(proxy_protocol_v2_enabled).lower() != current_tg_attributes.get('proxy_protocol_v2_enabled'):
+            update_attributes.append({'Key': 'proxy_protocol_v2.enabled', 'Value': str(proxy_protocol_v2_enabled).lower()})
 
     if update_attributes:
         try:
@@ -833,6 +869,8 @@ def main():
         stickiness_enabled=dict(type='bool'),
         stickiness_type=dict(),
         stickiness_lb_cookie_duration=dict(type='int'),
+        stickiness_app_cookie_duration=dict(type='int'),
+        stickiness_app_cookie_name=dict(),
         state=dict(required=True, choices=['present', 'absent']),
         successful_response_codes=dict(),
         tags=dict(default={}, type='dict'),
@@ -840,6 +878,8 @@ def main():
         targets=dict(type='list', elements='dict'),
         unhealthy_threshold_count=dict(type='int'),
         vpc_id=dict(),
+        preserve_client_ip_enabled=dict(type='bool'),
+        proxy_protocol_v2_enabled=dict(type='bool'),
         wait_timeout=dict(type='int', default=200),
         wait=dict(type='bool', default=False)
     )
