@@ -56,7 +56,8 @@ options:
     required: false
     aliases: [ account_id ]
     description:
-      - ID of account to delete/modify
+      - ID of account to delete/modify.
+      - Can also be used in account creation to work around vendor issues where the ID of the new user is required in the POST request.
     type: str
   new_username:
     required: false
@@ -86,6 +87,12 @@ options:
       - Timeout in seconds for URL requests to OOB controller
     default: 10
     type: int
+  boot_override_mode:
+    description:
+      - Boot mode when using an override.
+    type: str
+    choices: [ Legacy, UEFI ]
+    version_added: 3.5.0
   uefi_target:
     required: false
     description:
@@ -201,6 +208,15 @@ options:
         description:
           - The transfer method to use with the image
         type: str
+  strip_etag_quotes:
+    description:
+      - Removes surrounding quotes of etag used in C(If-Match) header
+        of C(PATCH) requests.
+      - Only use this option to resolve bad vendor implementation where
+        C(If-Match) only matches the unquoted etag string.
+    type: bool
+    default: false
+    version_added: 3.7.0
 
 author: "Jose Delarosa (@jose-delarosa)"
 '''
@@ -287,11 +303,29 @@ EXAMPLES = '''
       username: "{{ username }}"
       password: "{{ password }}"
 
+  - name: Set one-time boot to BiosSetup
+    community.general.redfish_command:
+      category: Systems
+      command: SetOneTimeBoot
+      boot_next: BiosSetup
+      boot_override_mode: Legacy
+      baseuri: "{{ baseuri }}"
+      username: "{{ username }}"
+      password: "{{ password }}"
+
   - name: Disable persistent boot device override
     community.general.redfish_command:
       category: Systems
       command: DisableBootOverride
 
+  - name: Set system indicator LED to blink using security token for auth
+    community.general.redfish_command:
+      category: Systems
+      command: IndicatorLedBlink
+      resource_id: 437XR1138R2
+      baseuri: "{{ baseuri }}"
+      auth_token: "{{ result.session.token }}"
+
   - name: Add user
     community.general.redfish_command:
       category: Accounts
@@ -557,7 +591,8 @@ from ansible.module_utils.common.text.converters import to_native
 # More will be added as module features are expanded
 CATEGORY_COMMANDS_ALL = {
     "Systems": ["PowerOn", "PowerForceOff", "PowerForceRestart", "PowerGracefulRestart",
-                "PowerGracefulShutdown", "PowerReboot", "SetOneTimeBoot", "EnableContinuousBootOverride", "DisableBootOverride"],
+                "PowerGracefulShutdown", "PowerReboot", "SetOneTimeBoot", "EnableContinuousBootOverride", "DisableBootOverride",
+                "IndicatorLedOn", "IndicatorLedOff", "IndicatorLedBlink"],
     "Chassis": ["IndicatorLedOn", "IndicatorLedOff", "IndicatorLedBlink"],
     "Accounts": ["AddUser", "EnableUser", "DeleteUser", "DisableUser",
                  "UpdateUserRole", "UpdateUserPassword", "UpdateUserName",
@@ -591,6 +626,7 @@ def main():
             timeout=dict(type='int', default=10),
             uefi_target=dict(),
             boot_next=dict(),
+            boot_override_mode=dict(choices=['Legacy', 'UEFI']),
             resource_id=dict(),
             update_image_uri=dict(),
             update_protocol=dict(),
@@ -614,7 +650,8 @@ def main():
                     transfer_protocol_type=dict(),
                     transfer_method=dict(),
                 )
-            )
+            ),
+            strip_etag_quotes=dict(type='bool', default=False),
         ),
         required_together=[
             ('username', 'password'),
@@ -662,16 +699,20 @@ def main():
     boot_opts = {
         'bootdevice': module.params['bootdevice'],
         'uefi_target': module.params['uefi_target'],
-        'boot_next': module.params['boot_next']
+        'boot_next': module.params['boot_next'],
+        'boot_override_mode': module.params['boot_override_mode'],
     }
 
     # VirtualMedia options
     virtual_media = module.params['virtual_media']
 
+    # Etag options
+    strip_etag_quotes = module.params['strip_etag_quotes']
+
     # Build root URI
     root_uri = "https://" + module.params['baseuri']
     rf_utils = RedfishUtils(creds, root_uri, timeout, module,
-                            resource_id=resource_id, data_modification=True)
+                            resource_id=resource_id, data_modification=True, strip_etag_quotes=strip_etag_quotes)
 
     # Check that Category is valid
     if category not in CATEGORY_COMMANDS_ALL:
@@ -722,6 +763,8 @@ def main():
             elif command == "DisableBootOverride":
                 boot_opts['override_enabled'] = 'Disabled'
                 result = rf_utils.set_boot_override(boot_opts)
+            elif command.startswith('IndicatorLed'):
+                result = rf_utils.manage_system_indicator_led(command)
 
     elif category == "Chassis":
         result = rf_utils._find_chassis_resource()
@@ -737,7 +780,7 @@ def main():
         else:
             for command in command_list:
                 if command in led_commands:
-                    result = rf_utils.manage_indicator_led(command)
+                    result = rf_utils.manage_chassis_indicator_led(command)
 
     elif category == "Sessions":
         # execute only if we find SessionService resources
