@@ -10,60 +10,77 @@ __metaclass__ = type
 DOCUMENTATION = '''
 module: xfconf
 author:
-    - "Joseph Benden (@jbenden)"
-    - "Alexei Znamensky (@russoz)"
+  - "Joseph Benden (@jbenden)"
+  - "Alexei Znamensky (@russoz)"
 short_description: Edit XFCE4 Configurations
 description:
-  - This module allows for the manipulation of Xfce 4 Configuration via
+  - This module allows for the manipulation of Xfce 4 Configuration with the help of
     xfconf-query.  Please see the xfconf-query(1) man pages for more details.
+seealso:
+  - name: C(xfconf-query) man page
+    description: Manual page of the C(xfconf-query) tool at the XFCE documentation site.
+    link: 'https://docs.xfce.org/xfce/xfconf/xfconf-query'
+
+  - name: xfconf - Configuration Storage System
+    description: XFCE documentation for the Xfconf configuration system.
+    link: 'https://docs.xfce.org/xfce/xfconf/start'
+
 options:
   channel:
     description:
-    - A Xfconf preference channel is a top-level tree key, inside of the
-      Xfconf repository that corresponds to the location for which all
-      application properties/keys are stored. See man xfconf-query(1)
-    required: yes
+      - A Xfconf preference channel is a top-level tree key, inside of the
+        Xfconf repository that corresponds to the location for which all
+        application properties/keys are stored. See man xfconf-query(1)
+    required: true
     type: str
   property:
     description:
-    - A Xfce preference key is an element in the Xfconf repository
-      that corresponds to an application preference. See man xfconf-query(1)
-    required: yes
+      - A Xfce preference key is an element in the Xfconf repository
+        that corresponds to an application preference. See man xfconf-query(1)
+    required: true
     type: str
   value:
     description:
-    - Preference properties typically have simple values such as strings,
-      integers, or lists of strings and integers. This is ignored if the state
-      is "get". For array mode, use a list of values. See man xfconf-query(1)
+      - Preference properties typically have simple values such as strings,
+        integers, or lists of strings and integers. This is ignored if the state
+        is "get". For array mode, use a list of values. See man xfconf-query(1)
     type: list
     elements: raw
   value_type:
     description:
-    - The type of value being set. This is ignored if the state is "get".
-      For array mode, use a list of types.
+      - The type of value being set. This is ignored if the state is "get".
+      - When providing more than one I(value_type), the length of the list must
+        be equal to the length of I(value).
+      - If only one I(value_type) is provided, but I(value) contains more than
+        on element, that I(value_type) will be applied to all elements of I(value).
+      - If the I(property) being set is an array and it can possibly have ony one
+        element in the array, then I(force_array=true) must be used to ensure
+        that C(xfconf-query) will interpret the value as an array rather than a
+        scalar.
+      - Support for C(uchar), C(char), C(uint64), and C(int64) has been added in community.general 4.8.0.
     type: list
     elements: str
-    choices: [ int, uint, bool, float, double, string ]
+    choices: [ string, int, double, bool, uint, uchar, char, uint64, int64, float ]
   state:
     type: str
     description:
-    - The action to take upon the property/value.
+      - The action to take upon the property/value.
+      - State C(get) is deprecated and will be removed in community.general 5.0.0. Please use the module M(community.general.xfconf_info) instead.
     choices: [ get, present, absent ]
     default: "present"
   force_array:
     description:
-    - Force array even if only one element
+      - Force array even if only one element
     type: bool
     default: 'no'
     aliases: ['array']
     version_added: 1.0.0
   disable_facts:
     description:
-    - For backward compatibility, output results are also returned as C(ansible_facts), but this behaviour is deprecated
-      and will be removed in community.general 4.0.0.
-    - This flag disables the output as facts and also disables the deprecation warning.
+      - The value C(false) is no longer allowed since community.general 4.0.0.
+      - This option will be deprecated in a future version, and eventually be removed.
     type: bool
-    default: no
+    default: true
     version_added: 2.1.0
 '''
 
@@ -88,7 +105,7 @@ EXAMPLES = """
     property: /general/workspace_names
     value_type: string
     value: ['Main']
-    force_array: yes
+    force_array: true
 """
 
 RETURN = '''
@@ -104,31 +121,34 @@ RETURN = '''
     sample: "/Xft/DPI"
   value_type:
     description:
-    - The type of the value that was changed (C(none) for C(get) and C(reset)
-      state). Either a single string value or a list of strings for array
-      types.
+      - The type of the value that was changed (C(none) for C(get) and C(reset)
+        state). Either a single string value or a list of strings for array
+        types.
+      - This is a string or a list of strings.
     returned: success
-    type: string or list of strings
+    type: any
     sample: '"int" or ["str", "str", "str"]'
   value:
     description:
-    - The value of the preference key after executing the module. Either a
-      single string value or a list of strings for array types.
+      - The value of the preference key after executing the module. Either a
+        single string value or a list of strings for array types.
+      - This is a string or a list of strings.
     returned: success
-    type: string or list of strings
+    type: any
     sample: '"192" or ["orange", "yellow", "violet"]'
   previous_value:
     description:
-    - The value of the preference key before executing the module (C(none) for
-      C(get) state). Either a single string value or a list of strings for array
-      types.
+      - The value of the preference key before executing the module (C(none) for
+        C(get) state). Either a single string value or a list of strings for array
+        types.
+      - This is a string or a list of strings.
     returned: success
-    type: string or list of strings
+    type: any
     sample: '"96" or ["red", "blue", "green"]'
 '''
 
 from ansible_collections.community.general.plugins.module_utils.module_helper import (
-    ModuleHelper, CmdMixin, StateMixin, ArgFormat
+    CmdStateModuleHelper, ArgFormat, ModuleHelperException
 )
 
 
@@ -151,23 +171,21 @@ class XFConfException(Exception):
     pass
 
 
-class XFConfProperty(CmdMixin, StateMixin, ModuleHelper):
+class XFConfProperty(CmdStateModuleHelper):
     change_params = 'value',
     diff_params = 'value',
     output_params = ('property', 'channel', 'value')
     facts_params = ('property', 'channel', 'value')
     module = dict(
         argument_spec=dict(
-            state=dict(default="present",
-                       choices=("present", "get", "absent"),
-                       type='str'),
-            channel=dict(required=True, type='str'),
-            property=dict(required=True, type='str'),
-            value_type=dict(required=False, type='list',
-                            elements='str', choices=('int', 'uint', 'bool', 'float', 'double', 'string')),
-            value=dict(required=False, type='list', elements='raw'),
-            force_array=dict(default=False, type='bool', aliases=['array']),
-            disable_facts=dict(type='bool', default=False),
+            state=dict(type='str', choices=("present", "get", "absent"), default="present"),
+            channel=dict(type='str', required=True),
+            property=dict(type='str', required=True),
+            value_type=dict(type='list', elements='str',
+                            choices=('string', 'int', 'double', 'bool', 'uint', 'uchar', 'char', 'uint64', 'int64', 'float')),
+            value=dict(type='list', elements='raw'),
+            force_array=dict(type='bool', default=False, aliases=['array']),
+            disable_facts=dict(type='bool', default=True),
         ),
         required_if=[('state', 'present', ['value', 'value_type'])],
         required_together=[('value', 'value_type')],
@@ -195,15 +213,8 @@ class XFConfProperty(CmdMixin, StateMixin, ModuleHelper):
         self.vars.set('type', self.vars.value_type, fact=True)
         self.vars.meta('value').set(initial_value=self.vars.previous_value)
 
-        if not self.module.params['disable_facts']:
-            self.facts_name = "xfconf"
-            self.module.deprecate(
-                msg="Returning results as facts is deprecated. "
-                    "Please register the module output to a variable instead."
-                    " You can use the disable_facts option to switch to the "
-                    "new behavior already now and disable this warning",
-                version="4.0.0", collection_name="community.general"
-            )
+        if self.module.params['disable_facts'] is False:
+            raise ModuleHelperException('Returning results as facts has been removed. Stop using disable_facts=false.')
 
     def process_command_output(self, rc, out, err):
         if err.rstrip() == self.does_not:
@@ -225,6 +236,10 @@ class XFConfProperty(CmdMixin, StateMixin, ModuleHelper):
     def state_get(self):
         self.vars.value = self.vars.previous_value
         self.vars.previous_value = None
+        self.module.deprecate(
+            msg="State 'get' is deprecated. Please use the module community.general.xfconf_info instead",
+            version="5.0.0", collection_name="community.general"
+        )
 
     def state_absent(self):
         if not self.module.check_mode:
@@ -272,8 +287,7 @@ class XFConfProperty(CmdMixin, StateMixin, ModuleHelper):
 
 
 def main():
-    xfconf = XFConfProperty()
-    xfconf.run()
+    XFConfProperty.execute()
 
 
 if __name__ == '__main__':
