@@ -404,7 +404,7 @@ import traceback
 
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
 
 # While vmadm(1M) supports a -E option to return any errors in JSON, the
 # generated JSON does not play well with the JSON parsers of Python.
@@ -684,7 +684,7 @@ def main():
             choices=['present', 'running', 'absent', 'deleted', 'stopped', 'created', 'restarted', 'rebooted']
         ),
         name=dict(
-            default=None, type='str',
+            type='str',
             aliases=['alias']
         ),
         brand=dict(
@@ -709,7 +709,7 @@ def main():
     # Add our 'simple' options to options dict.
     for type in properties:
         for p in properties[type]:
-            option = dict(default=None, type=type)
+            option = dict(type=type)
             options[p] = option
 
     module = AnsibleModule(
