@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright: (c) 2012, Brian Scholer (@briantist)
+# Copyright: (c) 2021, Brian Scholer (@briantist)
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import (absolute_import, division, print_function)
@@ -16,11 +16,13 @@ class ModuleDocFragment(object):
           - Authentication method to be used.
           - C(none) auth method was added in collection version C(1.2.0).
           - C(cert) auth method was added in collection version C(1.4.0).
+          - C(aws_iam_login) was renamed C(aws_iam) in collection version C(2.1.0). The old name will be removed in C(3.0.0).
         choices:
           - token
           - userpass
           - ldap
           - approle
+          - aws_iam
           - aws_iam_login
           - jwt
           - cert
@@ -50,8 +52,9 @@ class ModuleDocFragment(object):
         description:
           - For token auth, will perform a C(lookup-self) operation to determine the token's validity before using it.
           - Disable if your token does not have the C(lookup-self) capability.
+          - The default value is C(true).
+          - The default value will change to C(false) in version 4.0.0.
         type: bool
-        default: true
         version_added: 0.2.0
       username:
         description: Authentication user name.
@@ -61,7 +64,7 @@ class ModuleDocFragment(object):
         type: str
       role_id:
         description:
-          - Vault Role ID or name. Used in C(approle), C(aws_iam_login), and C(cert) auth methods.
+          - Vault Role ID or name. Used in C(approle), C(aws_iam), and C(cert) auth methods.
           - For C(cert) auth, if no I(role_id) is supplied, the default behavior is to try all certificate roles and return any one that matches.
         type: str
       secret_id:
