@@ -2,7 +2,7 @@
 # Copyright (c) 2021 Brian Scholer (@briantist)
 # Simplified BSD License (see licenses/simplified_bsd.txt or https://opensource.org/licenses/BSD-2-Clause)
 
-'''Python versions supported: all controller-side versions, all remote-side versions except 2.6'''
+'''Python versions supported: >=3.6'''
 
 # FOR INTERNAL COLLECTION USE ONLY
 # The interfaces in this file are meant for use within the community.hashi_vault collection
@@ -202,6 +202,7 @@ class HashiVaultOptionGroupBase:
         # key = option_name
         # value = dict with "env" key which is a list of env vars (in order of those checked first; process stops when value is found),
         # and an optional "default" key whose value will be set if none of the env vars are found.
+        # An optional boolean "required" key can be used to specify that a value is required, so raise if one is not found.
 
         for opt, config in option_vars.items():
             for env in config['env']:
@@ -212,16 +213,21 @@ class HashiVaultOptionGroupBase:
                 # in the argspec if it has late binding env vars.
                 if self._options.has_option(opt) and self._options.get_option(opt) is None:
                     self._options.set_option(opt, os.environ.get(env))
+
             if 'default' in config and self._options.has_option(opt) and self._options.get_option(opt) is None:
                 self._options.set_option(opt, config['default'])
 
+            if 'required' in config and self._options.get_option_default(opt) is None:
+                raise HashiVaultValueError("Required option %s was not set." % opt)
+
 
 class HashiVaultAuthMethodBase(HashiVaultOptionGroupBase):
     '''Base class for individual auth method implementations'''
 
-    def __init__(self, option_adapter, warning_callback):
+    def __init__(self, option_adapter, warning_callback, deprecate_callback):
         super(HashiVaultAuthMethodBase, self).__init__(option_adapter)
         self._warner = warning_callback
+        self._deprecator = deprecate_callback
 
     def validate(self):
         '''Validates the given auth method as much as possible without calling Vault.'''
@@ -239,3 +245,6 @@ class HashiVaultAuthMethodBase(HashiVaultOptionGroupBase):
 
     def warn(self, message):
         self._warner(message)
+
+    def deprecate(self, message, version=None, date=None, collection_name=None):
+        self._deprecator(message, version=version, date=date, collection_name=collection_name)
