@@ -5,7 +5,7 @@ from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
 DOCUMENTATION = """
-  lookup: vault_test_auth
+  name: vault_test_auth
   author:
     - Brian Scholer (@briantist)
   short_description: A plugin for testing centralized auth methods
