@@ -9,6 +9,9 @@
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
 
+from __future__ import (absolute_import, division, print_function)
+__metaclass__ = type
+
 DOCUMENTATION = '''
 ---
 module: avi_virtualservice
@@ -606,7 +609,7 @@ def main():
         sideband_profile=dict(type='dict',),
         snat_ip=dict(type='list',),
         sp_pool_refs=dict(type='list',),
-        ssl_key_and_certificate_refs=dict(type='list',),
+        ssl_key_and_certificate_refs=dict(type='list', no_log=False),
         ssl_profile_ref=dict(type='str',),
         ssl_profile_selectors=dict(type='list',),
         ssl_sess_cache_avg_size=dict(type='int',),
