@@ -53,14 +53,14 @@ options:
     description:
     - Comma separated list of database objects to set privileges on.
     - If I(type) is C(table), C(partition table), C(sequence), C(function) or C(procedure),
-      the special valueC(ALL_IN_SCHEMA) can be provided instead to specify all
-      database objects of type I(type) in the schema specified via I(schema).
+      the special value C(ALL_IN_SCHEMA) can be provided instead to specify all
+      database objects of I(type) in the schema specified via I(schema).
       (This also works with PostgreSQL < 9.0.) (C(ALL_IN_SCHEMA) is available
        for C(function) and C(partition table) since Ansible 2.8).
-    - C(procedure) is supported since PostgreSQL 11 and M(community.postgresql) collection 1.3.0.
+    - C(procedure) is supported since PostgreSQL 11 and community.postgresql collection 1.3.0.
     - If I(type) is C(database), this parameter can be omitted, in which case
       privileges are set for the database specified via I(database).
-    - If I(type) is I(function) or I(procedure), colons (":") in object names will be
+    - If I(type) is C(function) or C(procedure), colons (":") in object names will be
       replaced with commas (needed to specify signatures, see examples).
     type: str
     aliases:
