@@ -343,6 +343,14 @@ def set_search_path(cursor, search_path):
     cursor.execute('SET search_path TO %s' % search_path)
 
 
+def insane_query(string):
+    for c in string:
+        if c not in (' ', '\n', '', '\t'):
+            return False
+
+    return True
+
+
 def main():
     argument_spec = postgres_common_argument_spec()
     argument_spec.update(
@@ -401,7 +409,11 @@ def main():
 
                 if not as_single_query:
                     if ';' in query:
-                        query_list = [q for q in query.split(';') if q != '\n']
+                        for q in query.split(';'):
+                            if insane_query(q):
+                                continue
+                            else:
+                                query_list.append(q)
                     else:
                         query_list.append(query)
                 else:
