@@ -43,6 +43,25 @@ options:
         required: False
         type: list
         elements: str
+    lag_uplinks:
+        version_added: '1.12.0'
+        required: False
+        type: list
+        elements: dict
+        description:
+        - The ESXi hosts vmnics to use with specific LAGs.
+        suboptions:
+            lag:
+                description:
+                - Name of the LAG.
+                type: str
+                required: True
+            vmnics:
+                description:
+                - The ESXi hosts vmnics to use with the LAG.
+                required: False
+                type: list
+                elements: str
     state:
         description:
         - If the host should be present or absent attached to the vSwitch.
@@ -85,6 +104,25 @@ EXAMPLES = r'''
     state: present
   delegate_to: localhost
 
+- name: Add vmnics to LAGs
+  community.vmware.vmware_dvs_host:
+    hostname: '{{ vcenter_hostname }}'
+    username: '{{ vcenter_username }}'
+    password: '{{ vcenter_password }}'
+    esxi_hostname: '{{ esxi_hostname }}'
+    switch_name: dvSwitch
+    lag_uplinks:
+        - lag: lag1
+          vmnics:
+              - vmnic0
+              - vmnic1
+        - lag: lag2
+          vmnics:
+              - vmnic2
+              - vmnic3
+    state: present
+  delegate_to: localhost
+
 - name: Add Host to dVS/enable learnswitch (https://labs.vmware.com/flings/learnswitch)
   community.vmware.vmware_dvs_host:
     hostname: '{{ vcenter_hostname }}'
@@ -102,12 +140,6 @@ EXAMPLES = r'''
   delegate_to: localhost
 '''
 
-try:
-    from collections import Counter
-    HAS_COLLECTIONS_COUNTER = True
-except ImportError:
-    HAS_COLLECTIONS_COUNTER = False
-
 try:
     from pyVmomi import vim, vmodl
 except ImportError:
@@ -126,17 +158,32 @@ from ansible.module_utils._text import to_native
 class VMwareDvsHost(PyVmomi):
     def __init__(self, module):
         super(VMwareDvsHost, self).__init__(module)
-        self.dv_switch = None
         self.uplink_portgroup = None
         self.host = None
         self.dv_switch = None
-        self.nic = None
+        self.desired_state = {}
+
         self.state = self.module.params['state']
         self.switch_name = self.module.params['switch_name']
         self.esxi_hostname = self.module.params['esxi_hostname']
         self.vmnics = self.module.params['vmnics']
+        self.lag_uplinks = self.module.params['lag_uplinks']
         self.vendor_specific_config = self.module.params['vendor_specific_config']
 
+        self.dv_switch = find_dvs_by_name(self.content, self.switch_name)
+
+        if self.dv_switch is None:
+            self.module.fail_json(msg="A distributed virtual switch %s "
+                                      "does not exist" % self.switch_name)
+
+        self.lags = {}
+        for lag in self.dv_switch.config.lacpGroupConfig:
+            self.lags[lag.name] = lag
+
+        for lag_uplink in self.lag_uplinks:
+            if lag_uplink['lag'] not in self.lags:
+                self.module.fail_json(msg="LAG %s not found" % lag_uplink['lag'])
+
     def process_state(self):
         dvs_host_states = {
             'absent': {
@@ -179,15 +226,15 @@ class VMwareDvsHost(PyVmomi):
                 config.append(vim.dvs.KeyedOpaqueBlob(key=item['key'], opaqueData=item['value']))
             spec.host[0].vendorSpecificConfig = config
 
-        if operation in ("edit", "add"):
+        if operation == "edit":
             spec.host[0].backing = vim.dvs.HostMember.PnicBacking()
-            count = 0
 
-            for nic in self.vmnics:
-                spec.host[0].backing.pnicSpec.append(vim.dvs.HostMember.PnicSpec())
-                spec.host[0].backing.pnicSpec[count].pnicDevice = nic
-                spec.host[0].backing.pnicSpec[count].uplinkPortgroupKey = self.uplink_portgroup.key
-                count += 1
+            for nic, uplinkPortKey in self.desired_state.items():
+                pnicSpec = vim.dvs.HostMember.PnicSpec()
+                pnicSpec.pnicDevice = nic
+                pnicSpec.uplinkPortgroupKey = self.uplink_portgroup.key
+                pnicSpec.uplinkPortKey = uplinkPortKey
+                spec.host[0].backing.pnicSpec.append(pnicSpec)
 
         try:
             task = self.dv_switch.ReconfigureDvs_Task(spec)
@@ -220,6 +267,12 @@ class VMwareDvsHost(PyVmomi):
 
         if not self.module.check_mode:
             changed, result = self.modify_dvs_host(operation)
+            if changed:
+                self.set_desired_state()
+                changed, result = self.modify_dvs_host("edit")
+            else:
+                self.module.exit_json(changed=changed, result=to_native(result))
+
         self.module.exit_json(changed=changed, result=to_native(result))
 
     def find_host_attached_dvs(self):
@@ -229,23 +282,62 @@ class VMwareDvsHost(PyVmomi):
 
         return None
 
+    def set_desired_state(self):
+        lag_uplinks = []
+        switch_uplink_ports = {'non_lag': []}
+
+        portCriteria = vim.dvs.PortCriteria()
+        portCriteria.host = [self.host]
+        portCriteria.portgroupKey = self.uplink_portgroup.key
+        portCriteria.uplinkPort = True
+        ports = self.dv_switch.FetchDVPorts(portCriteria)
+
+        for name, lag in self.lags.items():
+            switch_uplink_ports[name] = []
+            for uplinkName in lag.uplinkName:
+                for port in ports:
+                    if port.config.name == uplinkName:
+                        switch_uplink_ports[name].append(port.key)
+                        lag_uplinks.append(port.key)
+
+        for port in sorted(ports, key=lambda port: port.config.name):
+            if port.key in self.uplink_portgroup.portKeys and port.key not in lag_uplinks:
+                switch_uplink_ports['non_lag'].append(port.key)
+
+        count = 0
+        for vmnic in self.vmnics:
+            self.desired_state[vmnic] = switch_uplink_ports['non_lag'][count]
+            count += 1
+
+        for lag in self.lag_uplinks:
+            count = 0
+            for vmnic in lag['vmnics']:
+                self.desired_state[vmnic] = switch_uplink_ports[lag['lag']][count]
+                count += 1
+
     def check_uplinks(self):
         pnic_device = []
 
-        for dvs_host_member in self.dv_switch.config.host:
-            if dvs_host_member.config.host == self.host:
-                for pnicSpec in dvs_host_member.config.backing.pnicSpec:
-                    pnic_device.append(pnicSpec.pnicDevice)
+        self.set_desired_state()
 
-        return Counter(pnic_device) == Counter(self.vmnics)
+        for dvs_host_member in self.dv_switch.config.host:
+            if dvs_host_member.config.host.name == self.esxi_hostname:
+                break
+
+        for pnicSpec in dvs_host_member.config.backing.pnicSpec:
+            pnic_device.append(pnicSpec.pnicDevice)
+            if pnicSpec.pnicDevice not in self.desired_state:
+                return False
+            if pnicSpec.uplinkPortKey != self.desired_state[pnicSpec.pnicDevice]:
+                return False
+
+        for vmnic in self.desired_state:
+            if vmnic not in pnic_device:
+                return False
+
+        return True
 
     def check_dvs_host_state(self):
-        self.dv_switch = find_dvs_by_name(self.content, self.switch_name)
-
-        if self.dv_switch is None:
-            self.module.fail_json(msg="A distributed virtual switch %s "
-                                      "does not exist" % self.switch_name)
-
         self.uplink_portgroup = self.find_dvs_uplink_pg()
 
         if self.uplink_portgroup is None:
@@ -262,6 +354,9 @@ class VMwareDvsHost(PyVmomi):
                 self.module.fail_json(msg="The esxi_hostname %s does not exist "
                                           "in vCenter" % self.esxi_hostname)
             return 'absent'
+        # Skip checking uplinks if the host should be absent, anyway
+        elif self.state == 'absent':
+            return 'present'
         else:
             if self.check_uplinks():
                 return 'present'
@@ -286,15 +381,30 @@ def main():
                     value=dict(type='str', required=True),
                 ),
             ),
+            lag_uplinks=dict(
+                type='list',
+                default=[],
+                required=False,
+                elements='dict',
+                options=dict(
+                    lag=dict(
+                        type='str',
+                        required=True,
+                    ),
+                    vmnics=dict(
+                        type='list',
+                        required=False,
+                        elements='str',
+                        default=[],
+                    ),
+                ),
+            ),
         )
     )
 
     module = AnsibleModule(argument_spec=argument_spec,
                            supports_check_mode=True)
 
-    if not HAS_COLLECTIONS_COUNTER:
-        module.fail_json(msg='collections.Counter from Python-2.7 is required for this module')
-
     vmware_dvs_host = VMwareDvsHost(module)
     vmware_dvs_host.process_state()
 
