@@ -121,6 +121,9 @@ options:
 extends_documentation_fragment:
 - community.zabbix.zabbix
 
+notes:
+- there where breaking changes in the Zabbix API with version 5.4 onwards (especially UUIDs) which may
+  require you to export the templates again (see version tag >= 5.4 in the resulting file/data).
 '''
 
 EXAMPLES = r'''
@@ -311,12 +314,13 @@ import traceback
 import re
 import xml.etree.ElementTree as ET
 
-from distutils.version import LooseVersion
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils._text import to_native
 from ansible.module_utils.six import PY2
 
 from ansible_collections.community.zabbix.plugins.module_utils.base import ZabbixBase
+from ansible_collections.community.zabbix.plugins.module_utils.version import LooseVersion
+
 import ansible_collections.community.zabbix.plugins.module_utils.helpers as zabbix_utils
 
 
@@ -352,15 +356,20 @@ class Template(ZabbixBase):
                 continue
             else:
                 template_id = template_list[0]['templateid']
-                template_ids.append(template_id)
+                template_ids.append({'templateid': template_id})
         return template_ids
 
     def add_template(self, template_name, group_ids, link_template_ids, macros):
         if self._module.check_mode:
             self._module.exit_json(changed=True)
 
-        self._zapi.template.create({'host': template_name, 'groups': group_ids, 'templates': link_template_ids,
-                                    'macros': macros})
+        new_template = {'host': template_name, 'groups': group_ids, 'templates': link_template_ids, 'macros': macros}
+        if macros is None:
+            new_template.update({'macros': []})
+        if link_template_ids is None:
+            new_template.update({'templates': []})
+
+        self._zapi.template.create(new_template)
 
     def check_template_changed(self, template_ids, template_groups, link_templates, clear_templates,
                                template_macros, template_content, template_type):
@@ -441,16 +450,20 @@ class Template(ZabbixBase):
 
         if template_macros is not None:
             template_changes.update({'macros': template_macros})
+        else:
+            template_changes.update({'macros': []})
 
         if template_changes:
             # If we got here we know that only one template was provided via template_name
-            template_changes.update({'templateid': template_ids[0]})
+            template_changes.update(template_ids[0])
             self._zapi.template.update(template_changes)
 
     def delete_template(self, templateids):
         if self._module.check_mode:
             self._module.exit_json(changed=True)
-        self._zapi.template.delete(templateids)
+
+        templateids_list = [t.get('templateid') for t in templateids]
+        self._zapi.template.delete(templateids_list)
 
     def ordered_json(self, obj):
         # Deep sort json dicts for comparison
@@ -462,8 +475,9 @@ class Template(ZabbixBase):
             return obj
 
     def dump_template(self, template_ids, template_type='json', omit_date=False):
+        template_ids_list = [t.get('templateid') for t in template_ids]
         try:
-            dump = self._zapi.configuration.export({'format': template_type, 'options': {'templates': template_ids}})
+            dump = self._zapi.configuration.export({'format': template_type, 'options': {'templates': template_ids_list}})
             if template_type == 'xml':
                 xmlroot = ET.fromstring(dump.encode('utf-8'))
                 # remove date field if requested
