@@ -107,6 +107,7 @@ ARGUMENTS_SPEC_CONTAINER = dict(
     read_only=dict(type='bool'),
     read_only_tmpfs=dict(type='bool'),
     recreate=dict(type='bool', default=False),
+    requires=dict(type='list', elements='str'),
     restart_policy=dict(type='str'),
     rm=dict(type='bool', aliases=['remove', 'auto_remove']),
     rootfs=dict(type='bool'),
@@ -520,6 +521,9 @@ class PodmanModuleParams:
     def addparam_read_only_tmpfs(self, c):
         return c + ['--read-only-tmpfs=%s' % self.params['read_only_tmpfs']]
 
+    def addparam_requires(self, c):
+        return c + ['--requires', ",".join(self.params['requires'])]
+
     def addparam_restart_policy(self, c):
         return c + ['--restart=%s' % self.params['restart_policy']]
 
@@ -641,7 +645,6 @@ class PodmanDefaults:
             "group_add": [],
             "ipc": "",
             "kernelmemory": "0",
-            "log_driver": "k8s-file",
             "log_level": "error",
             "memory": "0",
             "memory_swap": "0",
@@ -652,6 +655,7 @@ class PodmanDefaults:
             "oom_score_adj": 0,
             "pid": "",
             "privileged": False,
+            "read_only": False,
             "rm": False,
             "security_opt": [],
             "stop_signal": self.image_info['config'].get('stopsignal', "15"),
@@ -956,17 +960,11 @@ class PodmanContainerDiff:
 
     def diffparam_log_driver(self):
         before = self.info['hostconfig']['logconfig']['type']
-        after = self.params['log_driver']
-        return self._diff_update_and_compare('log_driver', before, after)
-
-    def diffparam_log_level(self):
-        excom = self.info['exitcommand']
-        if '--log-level' in excom:
-            before = excom[excom.index('--log-level') + 1].lower()
+        if self.module_params['log_driver'] is not None:
+            after = self.params['log_driver']
         else:
-            before = self.params['log_level']
-        after = self.params['log_level']
-        return self._diff_update_and_compare('log_level', before, after)
+            after = before
+        return self._diff_update_and_compare('log_driver', before, after)
 
     # Parameter has limited idempotency, unable to guess the default log_path
     def diffparam_log_opt(self):
@@ -1032,6 +1030,16 @@ class PodmanContainerDiff:
 
     def diffparam_mac_address(self):
         before = str(self.info['networksettings']['macaddress'])
+        if not before and self.info['networksettings'].get('networks'):
+            nets = self.info['networksettings']['networks']
+            macs = [
+                nets[i]["macaddress"] for i in nets if nets[i]["macaddress"]]
+            if macs:
+                before = macs[0]
+        if not before and 'createcommand' in self.info['config']:
+            cr_com = self.info['config']['createcommand']
+            if '--mac-address' in cr_com:
+                before = cr_com[cr_com.index('--mac-address') + 1].lower()
         if self.module_params['mac_address'] is not None:
             after = self.params['mac_address']
         else:
@@ -1142,6 +1150,11 @@ class PodmanContainerDiff:
         before, after = sorted(list(set(before))), sorted(list(set(after)))
         return self._diff_update_and_compare('publish', before, after)
 
+    def diffparam_read_only(self):
+        before = self.info['hostconfig']['readonlyrootfs']
+        after = self.params['read_only']
+        return self._diff_update_and_compare('read_only', before, after)
+
     def diffparam_rm(self):
         before = self.info['hostconfig']['autoremove']
         after = self.params['rm']
@@ -1223,9 +1236,14 @@ class PodmanContainerDiff:
             local_vols = []
             for m in before:
                 if m['type'] != 'volume':
-                    volumes.append([m['source'], m['destination']])
+                    volumes.append(
+                        [
+                            clean_volume(m['source']),
+                            clean_volume(m['destination'])
+                        ])
                 elif m['type'] == 'volume':
-                    local_vols.append([m['name'], m['destination']])
+                    local_vols.append(
+                        [m['name'], clean_volume(m['destination'])])
             before = [":".join(v) for v in volumes]
             before_local_vols = [":".join(v) for v in local_vols]
         if self.params['volume'] is not None:
