@@ -7,11 +7,6 @@
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-
-ANSIBLE_METADATA = {'metadata_version': '1.1',
-                    'status': ['preview'],
-                    'supported_by': 'certified'}
-
 DOCUMENTATION = r'''
 ---
 module: bigip_monitor_ldap
@@ -39,20 +34,17 @@ options:
   ip:
     description:
       - IP address part of the IP/port definition. If this parameter is not
-        provided when creating a new monitor, then the default value will be
-        '*'.
+        provided when creating a new monitor, the default value is '*'.
     type: str
   port:
     description:
       - Port address part of the IP/port definition. If this parameter is not
-        provided when creating a new monitor, then the default value will be
-        '*'.
-      - Note that if specifying an IP address, a value between 1 and 65535
-        must be specified.
+        provided when creating a new monitor, the default value is '*'.
+      - Note that if specifying an IP address, you must specify a value between 1 and 65535.
     type: str
   interval:
     description:
-      - Specifies, in seconds, the frequency at which the system issues the
+      - Specifies the frequency, in seconds, at which the system issues the
         monitor check when either the resource is down or the status of the
         resource is unknown.
     type: int
@@ -73,16 +65,16 @@ options:
         correctly to the monitor before setting the resource to 'up'.
       - During the interval, all responses from the resource must be correct.
       - When the interval expires, the resource is marked 'up'.
-      - A value of 0, means that the resource is marked up immediately upon
+      - A value of 0 means the resource is marked up immediately upon
         receipt of the first correct response.
     type: int
   up_interval:
     description:
       - Specifies the interval for the system to use to perform the health check
         when a resource is up.
-      - When C(0), specifies that the system uses the interval specified in
+      - When C(0), specifies the system uses the interval specified in
         C(interval) to check the health of the resource.
-      - When any other number, enables specification of a different interval to
+      - When any other number, enables you to specify a different interval to
         use when checking the health of a resource that is up.
     type: int
   manual_resume:
@@ -91,9 +83,9 @@ options:
         to B(enabled) at the next successful monitor check.
       - If you set this option to C(yes), you must manually re-enable the resource
         before the system can use it for load balancing connections.
-      - When C(yes), specifies that you must manually re-enable the resource after an
+      - When C(yes), specifies you must manually re-enable the resource after an
         unsuccessful monitor check.
-      - When C(no), specifies that the system automatically changes the status of a
+      - When C(no), specifies the system automatically changes the status of a
         resource to B(enabled) at the next successful monitor check.
     type: bool
   target_username:
@@ -115,7 +107,7 @@ options:
     type: str
   security:
     description:
-      - Specifies the secure protocol type for communications with the target.
+      - Specifies the secure protocol type for communication with the target.
     type: str
     choices:
       - none
@@ -128,7 +120,7 @@ options:
     type: bool
   chase_referrals:
     description:
-      - Specifies whether, upon receipt of an LDAP referral entry, the target
+      - Upon receipt of an LDAP referral entry, specifies whether the target
         follows (or chases) that referral.
     type: bool
   debug:
@@ -152,7 +144,7 @@ options:
     default: Common
   state:
     description:
-      - When C(present), ensures that the monitor exists.
+      - When C(present), ensures the monitor exists.
       - When C(absent), ensures the monitor is removed.
     type: str
     choices:
@@ -244,6 +236,8 @@ base:
   sample: base
 '''
 
+from datetime import datetime
+
 from ansible.module_utils.basic import (
     AnsibleModule, env_fallback
 )
@@ -254,6 +248,8 @@ from ..module_utils.common import (
 )
 from ..module_utils.compare import cmp_str_with_none
 from ..module_utils.ipaddress import is_valid_ip
+from ..module_utils.icontrol import tmos_version
+from ..module_utils.teem import send_teem
 
 
 class Parameters(AnsibleF5Parameters):
@@ -349,12 +345,6 @@ class Parameters(AnsibleF5Parameters):
     def manual_resume(self):
         return flatten_boolean(self._values['manual_resume'])
 
-    @property
-    def security(self):
-        if self._values['security'] in ['none', None]:
-            return ''
-        return self._values['security']
-
 
 class ApiParameters(Parameters):
     @property
@@ -376,6 +366,12 @@ class ApiParameters(Parameters):
             return None
         return self._values['description']
 
+    @property
+    def security(self):
+        if self._values['security'] in ['none', None]:
+            return ''
+        return self._values['security']
+
 
 class ModuleParameters(Parameters):
     @property
@@ -441,6 +437,12 @@ class ModuleParameters(Parameters):
             return ''
         return self._values['description']
 
+    @property
+    def security(self):
+        if self._values['security'] in ['none', None]:
+            return ''
+        return self._values['security']
+
 
 class Changes(Parameters):
     def to_return(self):
@@ -600,6 +602,8 @@ class ModuleManager(object):
         return False
 
     def exec_module(self):
+        start = datetime.now().isoformat()
+        version = tmos_version(self.client)
         changed = False
         result = dict()
         state = self.want.state
@@ -614,6 +618,7 @@ class ModuleManager(object):
         result.update(**changes)
         result.update(dict(changed=changed))
         self._announce_deprecations(result)
+        send_teem(start, self.client, self.module, version)
         return result
 
     def _announce_deprecations(self, result):
@@ -779,7 +784,8 @@ class ArgumentSpec(object):
             chase_referrals=dict(type='bool'),
             update_password=dict(
                 default='always',
-                choices=['always', 'on_create']
+                choices=['always', 'on_create'],
+                no_log=False
             ),
             state=dict(
                 default='present',
