@@ -97,7 +97,7 @@ options:
         suboptions:
             id:
                 type: int
-                description: no description
+                description: 'Id.'
 
 '''
 
@@ -169,6 +169,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -215,9 +220,29 @@ def main():
         'application_categories': {
             'required': False,
             'type': 'dict',
+            'revision': {
+                '6.0.0': True,
+                '6.2.1': True,
+                '6.2.3': True,
+                '6.2.5': True,
+                '6.4.0': True,
+                '6.4.2': True,
+                '6.4.5': True,
+                '7.0.0': True
+            },
             'options': {
                 'id': {
                     'required': True,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': True,
+                        '6.2.3': True,
+                        '6.2.5': True,
+                        '6.4.0': True,
+                        '6.4.2': True,
+                        '6.4.5': True,
+                        '7.0.0': True
+                    },
                     'type': 'int'
                 }
             }
@@ -234,9 +259,11 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
-        fmgr.process_curd()
+        fmgr.process_curd(argument_specs=module_arg_spec)
     else:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     module.exit_json(meta=module.params)
