@@ -24,7 +24,7 @@ ANSIBLE_METADATA = {'status': ['preview'],
 DOCUMENTATION = '''
 ---
 module: fmgr_dvmdb_workspace_commit_pkg
-short_description: Commit change(s) of a specific package, where the url includes both the folder(s) and name of the policy package.
+short_description: Commit change
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
@@ -92,7 +92,7 @@ EXAMPLES = '''
       ansible_httpapi_validate_certs: False
       ansible_httpapi_port: 443
    tasks:
-    - name: Commit change(s) of a specific package, where the url includes both the folder(s) and name of the policy package.
+    - name: Commit change
       fmgr_dvmdb_workspace_commit_pkg:
          bypass_validation: False
          workspace_locking_adom: <value in [global, custom adom including root]>
@@ -147,6 +147,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'bypass_validation': {
             'type': 'bool',
             'required': False,
@@ -188,9 +193,11 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, None, url_params, module, connection, top_level_schema_name=None)
         fmgr.validate_parameters(params_validation_blob)
-        fmgr.process_exec()
+        fmgr.process_exec(argument_specs=module_arg_spec)
     else:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     module.exit_json(meta=module.params)
