@@ -105,66 +105,66 @@ options:
                 type: str
                 description: 'Comment.'
             dynamic_mapping:
-                description: no description
+                description: 'Dynamic_Mapping.'
                 type: list
                 suboptions:
                     _scope:
-                        description: no description
+                        description: '_Scope.'
                         type: list
                         suboptions:
                             name:
                                 type: str
-                                description: no description
+                                description: 'Name.'
                             vdom:
                                 type: str
-                                description: no description
+                                description: 'Vdom.'
                     cache-ttl:
                         type: int
-                        description: no description
+                        description: 'Minimal TTL of individual IPv6 addresses in FQDN cache.'
                     color:
                         type: int
-                        description: no description
+                        description: 'Integer value to determine the color of the icon in the GUI (range 1 to 32, default = 0, which sets the value to 1).'
                     comment:
                         type: str
-                        description: no description
+                        description: 'Comment.'
                     end-ip:
                         type: str
-                        description: no description
+                        description: 'Final IP address (inclusive) in the range for the address (format: xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:xxxx).'
                     fqdn:
                         type: str
-                        description: no description
+                        description: 'Fully qualified domain name.'
                     host:
                         type: str
-                        description: no description
+                        description: 'Host Address.'
                     host-type:
                         type: str
-                        description: no description
+                        description: 'Host type.'
                         choices:
                             - 'any'
                             - 'specific'
                     ip6:
                         type: str
-                        description: no description
+                        description: 'IPv6 address prefix (format: xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:xxxx/xxx).'
                     obj-id:
                         type: str
-                        description: no description
+                        description: 'Object ID for NSX.'
                     sdn:
                         type: str
-                        description: no description
+                        description: 'SDN.'
                         choices:
                             - 'nsx'
                     start-ip:
                         type: str
-                        description: no description
+                        description: 'First IP address (inclusive) in the range for the address (format: xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:xxxx).'
                     tags:
                         type: str
-                        description: no description
+                        description: 'Tags.'
                     template:
                         type: str
-                        description: no description
+                        description: 'IPv6 address template.'
                     type:
                         type: str
-                        description: no description
+                        description: 'Type of IPv6 address object (default = ipprefix).'
                         choices:
                             - 'ipprefix'
                             - 'iprange'
@@ -173,44 +173,44 @@ options:
                             - 'template'
                     uuid:
                         type: str
-                        description: no description
+                        description: 'Universally Unique Identifier (UUID; automatically assigned but can be manually reset).'
                     visibility:
                         type: str
-                        description: no description
+                        description: 'Enable/disable the visibility of the object in the GUI.'
                         choices:
                             - 'disable'
                             - 'enable'
                     subnet-segment:
-                        description: no description
+                        description: 'Subnet-Segment.'
                         type: list
                         suboptions:
                             name:
                                 type: str
-                                description: no description
+                                description: 'Name.'
                             type:
                                 type: str
-                                description: no description
+                                description: 'Subnet segment type.'
                                 choices:
                                     - 'any'
                                     - 'specific'
                             value:
                                 type: str
-                                description: no description
+                                description: 'Subnet segment value.'
                     _image-base64:
                         type: str
-                        description: no description
+                        description: '_Image-Base64.'
                     end-mac:
                         type: str
-                        description: no description
+                        description: 'Last MAC address in the range.'
                     start-mac:
                         type: str
-                        description: no description
+                        description: 'First MAC address in the range.'
                     country:
                         type: str
-                        description: no description
+                        description: 'Country.'
                     global-object:
                         type: int
-                        description: no description
+                        description: 'Global-Object.'
                     fabric-object:
                         type: str
                         description: 'Security Fabric global object setting.'
@@ -218,7 +218,7 @@ options:
                             - 'disable'
                             - 'enable'
                     macaddr:
-                        description: no description
+                        description: 'Macaddr.'
                         type: str
             end-ip:
                 type: str
@@ -239,7 +239,7 @@ options:
                 type: str
                 description: 'IPv6 address prefix (format: xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:xxxx/xxx).'
             list:
-                description: no description
+                description: 'List.'
                 type: list
                 suboptions:
                     ip:
@@ -266,7 +266,7 @@ options:
                 type: str
                 description: 'First IP address (inclusive) in the range for the address (format: xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:xxxx).'
             subnet-segment:
-                description: no description
+                description: 'Subnet-Segment.'
                 type: list
                 suboptions:
                     name:
@@ -282,7 +282,7 @@ options:
                         type: str
                         description: 'Subnet segment value.'
             tagging:
-                description: no description
+                description: 'Tagging.'
                 type: list
                 suboptions:
                     category:
@@ -292,7 +292,7 @@ options:
                         type: str
                         description: 'Tagging entry name.'
                     tags:
-                        description: no description
+                        description: 'Tags.'
                         type: str
             template:
                 type: str
@@ -317,7 +317,7 @@ options:
                     - 'enable'
             _image-base64:
                 type: str
-                description: no description
+                description: '_Image-Base64.'
             end-mac:
                 type: str
                 description: 'Last MAC address in the range.'
@@ -337,13 +337,31 @@ options:
                     - 'disable'
                     - 'enable'
             macaddr:
-                description: no description
+                description: 'Multiple MAC address ranges.'
                 type: str
 
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the IPv6 addresses
+      fmgr_fact:
+        facts:
+            selector: 'firewall_address6'
+            params:
+                adom: 'ansible'
+                address6: ''
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -355,86 +373,13 @@ EXAMPLES = '''
     - name: Configure IPv6 firewall addresses.
       fmgr_firewall_address6:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         state: present
          firewall_address6:
-            cache-ttl: <value of integer>
-            color: <value of integer>
-            comment: <value of string>
-            dynamic_mapping:
-              -
-                  _scope:
-                    -
-                        name: <value of string>
-                        vdom: <value of string>
-                  cache-ttl: <value of integer>
-                  color: <value of integer>
-                  comment: <value of string>
-                  end-ip: <value of string>
-                  fqdn: <value of string>
-                  host: <value of string>
-                  host-type: <value in [any, specific]>
-                  ip6: <value of string>
-                  obj-id: <value of string>
-                  sdn: <value in [nsx]>
-                  start-ip: <value of string>
-                  tags: <value of string>
-                  template: <value of string>
-                  type: <value in [ipprefix, iprange, dynamic, ...]>
-                  uuid: <value of string>
-                  visibility: <value in [disable, enable]>
-                  subnet-segment:
-                    -
-                        name: <value of string>
-                        type: <value in [any, specific]>
-                        value: <value of string>
-                  _image-base64: <value of string>
-                  end-mac: <value of string>
-                  start-mac: <value of string>
-                  country: <value of string>
-                  global-object: <value of integer>
-                  fabric-object: <value in [disable, enable]>
-                  macaddr: <value of string>
-            end-ip: <value of string>
-            fqdn: <value of string>
-            host: <value of string>
-            host-type: <value in [any, specific]>
-            ip6: <value of string>
-            list:
-              -
-                  ip: <value of string>
-                  net-id: <value of string>
-                  obj-id: <value of string>
-            name: <value of string>
-            obj-id: <value of string>
-            sdn: <value in [nsx]>
-            start-ip: <value of string>
-            subnet-segment:
-              -
-                  name: <value of string>
-                  type: <value in [any, specific]>
-                  value: <value of string>
-            tagging:
-              -
-                  category: <value of string>
-                  name: <value of string>
-                  tags: <value of string>
-            template: <value of string>
-            type: <value in [ipprefix, iprange, dynamic, ...]>
-            uuid: <value of string>
-            visibility: <value in [disable, enable]>
-            _image-base64: <value of string>
-            end-mac: <value of string>
-            start-mac: <value of string>
-            country: <value of string>
-            global-object: <value of integer>
-            fabric-object: <value in [disable, enable]>
-            macaddr: <value of string>
-
+            host-type: any #<value in [any, specific]>
+            ip6: '::/55'
+            name: 'ansible-test'
+            visibility: disable
 '''
 
 RETURN = '''
@@ -481,6 +426,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -1456,6 +1406,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
