@@ -115,7 +115,26 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the the subnet segments in the IPv6 address
+      fmgr_fact:
+        facts:
+            selector: 'firewall_address6_subnetsegment'
+            params:
+                adom: 'ansible'
+                address6: 'ansible-test' # name
+                subnet-segment: ''
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -127,18 +146,13 @@ EXAMPLES = '''
     - name: IPv6 subnet segments.
       fmgr_firewall_address6_subnetsegment:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         address6: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         address6: 'ansible-test' # name
+         state: present
          firewall_address6_subnetsegment:
-            name: <value of string>
-            type: <value in [any, specific]>
-            value: <value of string>
-
+            name: 'ansible-test'
+            type: specific #<value in [any, specific]>
+            value: 'ansible'
 '''
 
 RETURN = '''
@@ -185,6 +199,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -306,6 +325,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
