@@ -125,7 +125,7 @@ options:
                         type: int
                         description: 'Integer value for the protocol type as defined by IANA (0 - 255).'
             entry:
-                description: no description
+                description: 'Entry.'
                 type: list
                 suboptions:
                     dst:
@@ -135,7 +135,7 @@ options:
                         type: int
                         description: 'Entry ID(1-255).'
                     port-range:
-                        description: no description
+                        description: 'Port-Range.'
                         type: list
                         suboptions:
                             end-port:
@@ -166,7 +166,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -175,42 +175,42 @@ EXAMPLES = '''
       ansible_httpapi_validate_certs: False
       ansible_httpapi_port: 443
    tasks:
+    - name: Configure custom Internet Services via Generic Module.
+      fmgr_generic:
+         method: 'set'
+         params:
+             - url: '/pm/config/adom/ansible/obj/firewall/internet-service-custom'
+               data:
+                 - name: 'ansible-test'
+                   comment: 'ansible-comment'
     - name: Configure custom Internet Services.
+      when: False
       fmgr_firewall_internetservicecustom:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         state: present
          firewall_internetservicecustom:
-            comment: <value of string>
-            disable-entry:
-              -
-                  id: <value of integer>
-                  ip-range:
-                    -
-                        end-ip: <value of string>
-                        id: <value of integer>
-                        start-ip: <value of string>
-                  port: <value of integer>
-                  protocol: <value of integer>
-            entry:
-              -
-                  dst: <value of string>
-                  id: <value of integer>
-                  port-range:
-                    -
-                        end-port: <value of integer>
-                        id: <value of integer>
-                        start-port: <value of integer>
-                  protocol: <value of integer>
-            master-service-id: <value of string>
-            name: <value of string>
-            reputation: <value of integer>
-            id: <value of integer>
+            comment: 'ansible-comment'
+            name: 'ansible-test'
 
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the custom Internet Services
+      fmgr_fact:
+        facts:
+            selector: 'firewall_internetservicecustom'
+            params:
+                adom: 'ansible'
+                internet-service-custom: ''
 '''
 
 RETURN = '''
@@ -257,6 +257,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -602,7 +607,7 @@ def main():
                     'type': 'int'
                 },
                 'id': {
-                    'required': True,
+                    'required': False,
                     'revision': {
                         '6.4.2': True,
                         '6.4.5': True,
@@ -624,6 +629,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
