@@ -116,7 +116,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -128,19 +128,34 @@ EXAMPLES = '''
     - name: IP ranges in the disable entry.
       fmgr_firewall_internetservicecustom_disableentry_iprange:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         internet-service-custom: <your own value>
-         disable-entry: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         internet-service-custom: 'ansible-test' # name
+         disable-entry: '1' # id
+         state: present
          firewall_internetservicecustom_disableentry_iprange:
-            end-ip: <value of string>
-            id: <value of integer>
-            start-ip: <value of string>
-
+            end-ip: '0.0.0.20'
+            id: 1
+            start-ip: '0.0.0.0'
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the ipranges in the disabled entry
+      fmgr_fact:
+        facts:
+            selector: 'firewall_internetservicecustom_disableentry_iprange'
+            params:
+                adom: 'ansible'
+                internet-service-custom: 'ansible-test' # name
+                disable-entry: '1' # id
+                ip-range: ''
 '''
 
 RETURN = '''
@@ -187,6 +202,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -241,17 +261,50 @@ def main():
         'firewall_internetservicecustom_disableentry_iprange': {
             'required': False,
             'type': 'dict',
+            'revision': {
+                '6.0.0': True
+            },
             'options': {
                 'end-ip': {
                     'required': False,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': False,
+                        '6.2.3': False,
+                        '6.2.5': False,
+                        '6.4.0': False,
+                        '6.4.2': False,
+                        '6.4.5': False,
+                        '7.0.0': False
+                    },
                     'type': 'str'
                 },
                 'id': {
                     'required': True,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': False,
+                        '6.2.3': False,
+                        '6.2.5': False,
+                        '6.4.0': False,
+                        '6.4.2': False,
+                        '6.4.5': False,
+                        '7.0.0': False
+                    },
                     'type': 'int'
                 },
                 'start-ip': {
                     'required': False,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': False,
+                        '6.2.3': False,
+                        '6.2.5': False,
+                        '6.4.0': False,
+                        '6.4.2': False,
+                        '6.4.5': False,
+                        '7.0.0': False
+                    },
                     'type': 'str'
                 }
             }
@@ -268,9 +321,11 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
-        fmgr.process_curd()
+        fmgr.process_curd(argument_specs=module_arg_spec)
     else:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     module.exit_json(meta=module.params)
