@@ -105,7 +105,7 @@ options:
                 type: str
                 description: 'Comment.'
             entries:
-                description: no description
+                description: 'Entries.'
                 type: list
                 suboptions:
                     action:
@@ -117,10 +117,10 @@ options:
                             - 'reset'
                             - 'default'
                     application:
-                        description: no description
+                        description: 'Applications to be protected. set application ? lists available applications. all includes all applications. other includes all unlisted applications.'
                         type: str
                     exempt-ip:
-                        description: no description
+                        description: 'Exempt-Ip.'
                         type: list
                         suboptions:
                             dst-ip:
@@ -136,7 +136,7 @@ options:
                         type: int
                         description: 'Rule ID in IPS database (0 - 4294967295).'
                     location:
-                        description: no description
+                        description: 'Protect client or server traffic.'
                         type: str
                     log:
                         type: str
@@ -157,10 +157,10 @@ options:
                             - 'disable'
                             - 'enable'
                     os:
-                        description: no description
+                        description: 'Operating systems to be protected.  all includes all operating systems. other includes all unlisted operating systems.'
                         type: str
                     protocol:
-                        description: no description
+                        description: 'Protocols to be examined. set protocol ? lists available protocols. all includes all protocols. other includes all unlisted protocols.'
                         type: str
                     quarantine:
                         type: str
@@ -204,7 +204,7 @@ options:
                         type: str
                         description: 'Identifies the predefined or custom IPS signatures to add to the sensor.'
                     severity:
-                        description: no description
+                        description: 'Relative severity of the signature, from info to critical. Log messages generated by the signature include the severity.'
                         type: str
                     status:
                         type: str
@@ -214,7 +214,7 @@ options:
                             - 'enable'
                             - 'default'
                     cve:
-                        description: no description
+                        description: 'List of CVE IDs of the signatures to add to the sensor'
                         type: str
             extended-log:
                 type: str
@@ -369,7 +369,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -381,77 +381,31 @@ EXAMPLES = '''
     - name: Configure IPS sensor.
       fmgr_ips_sensor:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         state: present
          ips_sensor:
-            block-malicious-url: <value in [disable, enable]>
-            comment: <value of string>
-            entries:
-              -
-                  action: <value in [pass, block, reset, ...]>
-                  application: <value of string>
-                  exempt-ip:
-                    -
-                        dst-ip: <value of string>
-                        id: <value of integer>
-                        src-ip: <value of string>
-                  id: <value of integer>
-                  location: <value of string>
-                  log: <value in [disable, enable]>
-                  log-attack-context: <value in [disable, enable]>
-                  log-packet: <value in [disable, enable]>
-                  os: <value of string>
-                  protocol: <value of string>
-                  quarantine: <value in [none, attacker, both, ...]>
-                  quarantine-expiry: <value of string>
-                  quarantine-log: <value in [disable, enable]>
-                  rate-count: <value of integer>
-                  rate-duration: <value of integer>
-                  rate-mode: <value in [periodical, continuous]>
-                  rate-track: <value in [none, src-ip, dest-ip, ...]>
-                  rule: <value of string>
-                  severity: <value of string>
-                  status: <value in [disable, enable, default]>
-                  cve: <value of string>
-            extended-log: <value in [disable, enable]>
-            filter:
-              -
-                  action: <value in [pass, block, default, ...]>
-                  application: <value of string>
-                  location: <value of string>
-                  log: <value in [disable, enable, default]>
-                  log-packet: <value in [disable, enable, default]>
-                  name: <value of string>
-                  os: <value of string>
-                  protocol: <value of string>
-                  quarantine: <value in [none, attacker, both, ...]>
-                  quarantine-expiry: <value of integer>
-                  quarantine-log: <value in [disable, enable]>
-                  severity: <value of string>
-                  status: <value in [disable, enable, default]>
-            name: <value of string>
-            override:
-              -
-                  action: <value in [pass, block, reset]>
-                  exempt-ip:
-                    -
-                        dst-ip: <value of string>
-                        id: <value of integer>
-                        src-ip: <value of string>
-                  log: <value in [disable, enable]>
-                  log-packet: <value in [disable, enable]>
-                  quarantine: <value in [none, attacker, both, ...]>
-                  quarantine-expiry: <value of integer>
-                  quarantine-log: <value in [disable, enable]>
-                  rule-id: <value of integer>
-                  status: <value in [disable, enable]>
-            replacemsg-group: <value of string>
-            scan-botnet-connections: <value in [disable, block, monitor]>
+            block-malicious-url: disable
+            comment: 'ansible-comment'
+            name: 'ansible-test-ipssensor'
 
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the IPS sensors
+      fmgr_fact:
+        facts:
+            selector: 'ips_sensor'
+            params:
+                adom: 'ansible'
+                sensor: ''
 '''
 
 RETURN = '''
@@ -498,6 +452,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -1500,6 +1459,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
