@@ -122,10 +122,10 @@ options:
                     - 'primary'
                     - 'secondary'
             password:
-                description: no description
+                description: 'Group password.'
                 type: str
             peer:
-                description: no description
+                description: 'Peer.'
                 type: list
                 suboptions:
                     id:
@@ -236,6 +236,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -486,6 +491,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_partial_curd(argument_specs=module_arg_spec)
