@@ -45,8 +45,7 @@ except ImportError:
 
 
 class Bgp_globalFacts(object):
-    """ The junos bgp_global fact class
-    """
+    """The junos bgp_global fact class"""
 
     def __init__(self, module, subspec="config", options="options"):
         self._module = module
@@ -72,7 +71,7 @@ class Bgp_globalFacts(object):
         return connection.get_configuration(filter=config_filter)
 
     def populate_facts(self, connection, ansible_facts, data=None):
-        """ Populate the facts for bgp_global
+        """Populate the facts for bgp_global
         :param connection: the device connection
         :param ansible_facts: Facts dictionary
         :param data: previously collected conf
