@@ -71,7 +71,7 @@ options:
     - present
     default: present
 notes:
-- For a general purpose network module, see the M(ansible.netcommon..net_ping) module.
+- For a general purpose network module, see the M(ansible.netcommon.net_ping) module.
 - For Windows targets, use the M(ansible.windows.win_ping) module instead.
 - For targets running Python, use the M(ansible.builtin.ping) module instead.
 - This module works only with connection C(network_cli).
@@ -147,8 +147,7 @@ from ansible_collections.junipernetworks.junos.plugins.module_utils.network.juno
 
 
 def main():
-    """ main entry point for module execution
-    """
+    """main entry point for module execution"""
     argument_spec = dict(
         count=dict(type="int", default=5),
         dest=dict(type="str", required=True),
