@@ -9,23 +9,16 @@ import json
 import sys
 
 import pytest
-from requests import Response
+try:
+    from requests import Response
+except ImportError:
+    if sys.version_info < (2, 7):
+        pytestmark = pytest.mark.skip('Skipping Unit Tests on 2.6 as requests is not be available')
 
 from ansible.module_utils import basic
 from ansible.module_utils._text import to_bytes
 from ansible_collections.netapp.azure.tests.unit.compat.mock import patch, Mock
 
-
-# We can't import ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common in the UT environment
-# and anyway, it's better to remove any external dependency in UTs.
-class MockAzureRMModuleBase(object):
-    ''' dummy base class for AzureRMNetAppModuleBase '''
-
-
-mocked_module = type(sys)('mock_azure_import')
-mocked_module.AzureRMModuleBase = MockAzureRMModuleBase
-sys.modules['ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common'] = mocked_module
-
 HAS_AZURE_RMNETAPP_IMPORT = True
 try:
     # At this point, python believes the module is already loaded, so the import inside azure_rm_netapp_volume will be skipped.
@@ -34,9 +27,6 @@ try:
 except ImportError:
     HAS_AZURE_RMNETAPP_IMPORT = False
 
-# clean up to avoid side effects
-del sys.modules['ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common']
-
 HAS_AZURE_CLOUD_ERROR_IMPORT = True
 try:
     from msrestazure.azure_exceptions import CloudError
@@ -81,16 +71,16 @@ class MockAzureClient(object):
         self.valid_volumes = ['test1', 'test2']
 
     def get(self, resource_group, account_name, pool_name, volume_name):  # pylint: disable=unused-argument
-        if volume_name not in self.valid_volumes:
-            invalid = Response()
-            invalid.status_code = 404
-            raise CloudError(response=invalid)
-        else:
+        if volume_name in self.valid_volumes:
             return Mock(name=volume_name,
                         subnet_id='/resid/whatever/subnet_name',
                         mount_targets=[Mock(ip_address='1.2.3.4')]
                         )
 
+        invalid = Response()
+        invalid.status_code = 404
+        raise CloudError(response=invalid)
+
     def create_or_update(self, body, resource_group, account_name, pool_name, volume_name):             # pylint: disable=unused-argument
         return None
 
@@ -144,10 +134,11 @@ def set_default_args():
         'name': name,
         'location': location,
         'file_path': file_path,
-        'subnet_id': subnet_id,
+        'subnet_name': subnet_id,
         'virtual_network': virtual_network,
         'size': size,
-        'protocol_types': 'nfs'
+        'protocol_types': 'nfs',
+        'tags': {'owner': 'laurentn'}
     })
 
 
@@ -160,10 +151,8 @@ def test_module_fail_when_required_args_missing(patch_ansible):     # pylint: di
 
 
 @patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.netapp_client')
-@patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.__init__')
-def test_ensure_get_called_valid_volume(mock_base, client_f):
+def test_ensure_get_called_valid_volume(client_f):
     set_module_args(set_default_args())
-    mock_base.return_value = Mock()
     client_f.return_value = Mock()
     my_obj = volume_module()
     my_obj.netapp_client.volumes = MockAzureClient()
@@ -171,12 +160,10 @@ def test_ensure_get_called_valid_volume(mock_base, client_f):
 
 
 @patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.netapp_client')
-@patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.__init__')
-def test_ensure_get_called_non_existing_volume(mock_base, client_f):
-    data = set_default_args()
+def test_ensure_get_called_non_existing_volume(client_f):
+    data = dict(set_default_args())
     data['name'] = 'invalid'
     set_module_args(data)
-    mock_base.return_value = Mock()
     client_f.return_value = Mock()
     my_obj = volume_module()
     my_obj.netapp_client.volumes = MockAzureClient()
@@ -184,11 +171,10 @@ def test_ensure_get_called_non_existing_volume(mock_base, client_f):
 
 
 @patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.netapp_client')
-@patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.__init__')
 @patch('ansible_collections.netapp.azure.plugins.modules.azure_rm_netapp_volume.AzureRMNetAppVolume.get_azure_netapp_volume')
 @patch('ansible_collections.netapp.azure.plugins.modules.azure_rm_netapp_volume.AzureRMNetAppVolume.create_azure_netapp_volume')
-def test_ensure_create_called(mock_create, mock_get, mock_base, client_f, patch_ansible):   # pylint: disable=unused-argument
-    data = set_default_args()
+def test_ensure_create_called(mock_create, mock_get, client_f, patch_ansible):   # pylint: disable=unused-argument
+    data = dict(set_default_args())
     data['name'] = 'create'
     set_module_args(data)
     mock_get.side_effect = [
@@ -196,12 +182,14 @@ def test_ensure_create_called(mock_create, mock_get, mock_base, client_f, patch_
         dict(mount_targets=[dict(ip_address='11.22.33.44')],        # get after create
              creation_token='abcd')
     ]
-    mock_base.return_value = Mock()
     client_f.return_value = Mock()
     my_obj = volume_module()
     my_obj.netapp_client.volumes = MockAzureClient()
     with pytest.raises(AnsibleExitJson) as exc:
-        my_obj.exec_module()
+        # add default args for exec_module
+        data['state'] = 'present'
+        data['debug'] = False
+        my_obj.exec_module(**data)
     assert exc.value.args[0]['changed']
     expected_mount_path = '11.22.33.44:/abcd'
     assert exc.value.args[0]['mount_path'] == expected_mount_path
@@ -209,36 +197,36 @@ def test_ensure_create_called(mock_create, mock_get, mock_base, client_f, patch_
 
 
 @patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.netapp_client')
-@patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.__init__')
 @patch('ansible_collections.netapp.azure.plugins.modules.azure_rm_netapp_volume.AzureRMNetAppVolume.get_azure_netapp_volume')
-def test_create(mock_get, mock_base, client_f, patch_ansible):  # pylint: disable=unused-argument
-    data = set_default_args()
+def test_create(mock_get, client_f, patch_ansible):  # pylint: disable=unused-argument
+    data = dict(set_default_args())
     data['name'] = 'create'
-    data['protocol_types'] = 'nfsv4.1'
+    data['protocol_types'] = ['nfsv4.1']
     set_module_args(data)
     mock_get.side_effect = [
         None,                                                       # first get
         dict(mount_targets=[dict(ip_address='11.22.33.44')],        # get after create
              creation_token='abcd')
     ]
-    mock_base.return_value = Mock()
     client_f.return_value = Mock()
     my_obj = volume_module()
     my_obj.azure_auth = Mock(subscription_id='1234')
     my_obj._new_style = True
     my_obj.netapp_client.volumes = MockAzureClient()
     with pytest.raises(AnsibleExitJson) as exc:
-        my_obj.exec_module()
+        # add default args for exec_module
+        data['state'] = 'present'
+        data['debug'] = False
+        my_obj.exec_module(**data)
     assert exc.value.args[0]['changed']
     expected_mount_path = '11.22.33.44:/abcd'
     assert exc.value.args[0]['mount_path'] == expected_mount_path
 
 
 @patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.netapp_client')
-@patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.__init__')
 @patch('ansible_collections.netapp.azure.plugins.modules.azure_rm_netapp_volume.AzureRMNetAppVolume.get_azure_netapp_volume')
-def test_create_exception(mock_get, mock_base, client_f, patch_ansible):    # pylint: disable=unused-argument
-    data = set_default_args()
+def test_create_exception(mock_get, client_f, patch_ansible):    # pylint: disable=unused-argument
+    data = dict(set_default_args())
     data['name'] = 'create'
     data['protocol_types'] = 'nfsv4.1'
     set_module_args(data)
@@ -247,24 +235,25 @@ def test_create_exception(mock_get, mock_base, client_f, patch_ansible):    # py
         dict(mount_targets=[dict(ip_address='11.22.33.44')],        # get after create
              creation_token='abcd')
     ]
-    mock_base.return_value = Mock()
     client_f.return_value = Mock()
     my_obj = volume_module()
     my_obj.azure_auth = Mock(subscription_id='1234')
     my_obj._new_style = True
     my_obj.netapp_client.volumes = MockAzureClientRaise()
     with pytest.raises(AnsibleFailJson) as exc:
-        my_obj.exec_module()
+        # add default args for exec_module
+        data['state'] = 'present'
+        data['debug'] = False
+        my_obj.exec_module(**data)
     expected_msg = 'Error creating volume'
     assert expected_msg in exc.value.args[0]['msg']
 
 
 @patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.netapp_client')
-@patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.__init__')
 @patch('ansible_collections.netapp.azure.plugins.modules.azure_rm_netapp_volume.AzureRMNetAppVolume.get_azure_netapp_volume')
 @patch('ansible_collections.netapp.azure.plugins.modules.azure_rm_netapp_volume.AzureRMNetAppVolume.create_azure_netapp_volume')
-def test_ensure_create_called_but_fail_on_get(mock_create, mock_get, mock_base, client_f, patch_ansible):   # pylint: disable=unused-argument
-    data = set_default_args()
+def test_ensure_create_called_but_fail_on_get(mock_create, mock_get, client_f, patch_ansible):   # pylint: disable=unused-argument
+    data = dict(set_default_args())
     data['name'] = 'create'
     set_module_args(data)
     mock_get.side_effect = [
@@ -272,61 +261,63 @@ def test_ensure_create_called_but_fail_on_get(mock_create, mock_get, mock_base,
         dict(mount_targets=None,                                    # get after create
              creation_token='abcd')
     ]
-    mock_base.return_value = Mock()
     client_f.return_value = Mock()
     my_obj = volume_module()
     my_obj.netapp_client.volumes = MockAzureClient()
     with pytest.raises(AnsibleFailJson) as exc:
-        my_obj.exec_module()
+        # add default args for exec_module
+        data['state'] = 'present'
+        data['debug'] = False
+        my_obj.exec_module(**data)
     error = 'Error: volume create was created successfully, but mount target(s) cannot be found - volume details:'
     assert exc.value.args[0]['msg'].startswith(error)
     mock_create.assert_called_with()
 
 
 @patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.netapp_client')
-@patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.__init__')
 @patch('ansible_collections.netapp.azure.plugins.modules.azure_rm_netapp_volume.AzureRMNetAppVolume.get_azure_netapp_volume')
 @patch('ansible_collections.netapp.azure.plugins.modules.azure_rm_netapp_volume.AzureRMNetAppVolume.create_azure_netapp_volume')
-def test_ensure_create_called_but_fail_on_mount_target(mock_create, mock_get, mock_base, client_f, patch_ansible):  # pylint: disable=unused-argument
-    data = set_default_args()
+def test_ensure_create_called_but_fail_on_mount_target(mock_create, mock_get, client_f, patch_ansible):  # pylint: disable=unused-argument
+    data = dict(set_default_args())
     data['name'] = 'create'
     set_module_args(data)
     mock_get.return_value = None
-    mock_base.return_value = Mock()
     client_f.return_value = Mock()
     my_obj = volume_module()
     my_obj.netapp_client.volumes = MockAzureClient()
     with pytest.raises(AnsibleFailJson) as exc:
-        my_obj.exec_module()
+        # add default args for exec_module
+        data['state'] = 'present'
+        data['debug'] = False
+        my_obj.exec_module(**data)
     error = 'Error: volume create was created successfully, but cannot be found.'
     assert exc.value.args[0]['msg'] == error
     mock_create.assert_called_with()
 
 
 @patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.netapp_client')
-@patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.__init__')
 @patch('ansible_collections.netapp.azure.plugins.modules.azure_rm_netapp_volume.AzureRMNetAppVolume.get_azure_netapp_volume')
 @patch('ansible_collections.netapp.azure.plugins.modules.azure_rm_netapp_volume.AzureRMNetAppVolume.delete_azure_netapp_volume')
-def test_ensure_delete_called(mock_delete, mock_get, mock_base, client_f, patch_ansible):   # pylint: disable=unused-argument
-    data = set_default_args()
+def test_ensure_delete_called(mock_delete, mock_get, client_f, patch_ansible):   # pylint: disable=unused-argument
+    data = dict(set_default_args())
     data['state'] = 'absent'
     set_module_args(data)
-    mock_base.return_value = Mock()
     client_f.return_value = Mock()
     mock_get.return_value = Mock()
     my_obj = volume_module()
     my_obj.netapp_client.volumes = MockAzureClient()
     with pytest.raises(AnsibleExitJson) as exc:
-        my_obj.exec_module()
+        # add default args for exec_module
+        data['debug'] = False
+        my_obj.exec_module(**data)
     assert exc.value.args[0]['changed']
     mock_delete.assert_called_with()
 
 
 @patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.netapp_client')
-@patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.__init__')
 @patch('ansible_collections.netapp.azure.plugins.modules.azure_rm_netapp_volume.AzureRMNetAppVolume.get_azure_netapp_volume')
-def test_delete(mock_get, mock_base, client_f, patch_ansible):  # pylint: disable=unused-argument
-    data = set_default_args()
+def test_delete(mock_get, client_f, patch_ansible):  # pylint: disable=unused-argument
+    data = dict(set_default_args())
     data['name'] = 'delete'
     data['state'] = 'absent'
     set_module_args(data)
@@ -334,24 +325,24 @@ def test_delete(mock_get, mock_base, client_f, patch_ansible):  # pylint: disabl
         dict(mount_targets=[dict(ip_address='11.22.33.44')],        # first get
              creation_token='abcd')
     ]
-    mock_base.return_value = Mock()
     client_f.return_value = Mock()
     my_obj = volume_module()
     my_obj.azure_auth = Mock(subscription_id='1234')
     my_obj._new_style = True
     my_obj.netapp_client.volumes = MockAzureClient()
     with pytest.raises(AnsibleExitJson) as exc:
-        my_obj.exec_module()
+        # add default args for exec_module
+        data['debug'] = False
+        my_obj.exec_module(**data)
     assert exc.value.args[0]['changed']
     expected_mount_path = ''
     assert exc.value.args[0]['mount_path'] == expected_mount_path
 
 
 @patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.netapp_client')
-@patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.__init__')
 @patch('ansible_collections.netapp.azure.plugins.modules.azure_rm_netapp_volume.AzureRMNetAppVolume.get_azure_netapp_volume')
-def test_delete_exception(mock_get, mock_base, client_f, patch_ansible):    # pylint: disable=unused-argument
-    data = set_default_args()
+def test_delete_exception(mock_get, client_f, patch_ansible):    # pylint: disable=unused-argument
+    data = dict(set_default_args())
     data['name'] = 'delete'
     data['state'] = 'absent'
     set_module_args(data)
@@ -359,52 +350,56 @@ def test_delete_exception(mock_get, mock_base, client_f, patch_ansible):    # py
         dict(mount_targets=[dict(ip_address='11.22.33.44')],        # first get
              creation_token='abcd')
     ]
-    mock_base.return_value = Mock()
     client_f.return_value = Mock()
     my_obj = volume_module()
     my_obj.azure_auth = Mock(subscription_id='1234')
     my_obj._new_style = True
     my_obj.netapp_client.volumes = MockAzureClientRaise()
     with pytest.raises(AnsibleFailJson) as exc:
-        my_obj.exec_module()
+        # add default args for exec_module
+        data['debug'] = False
+        my_obj.exec_module(**data)
     expected_msg = 'Error deleting volume'
     assert expected_msg in exc.value.args[0]['msg']
 
 
 @patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.netapp_client')
-@patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.__init__')
 @patch('ansible_collections.netapp.azure.plugins.modules.azure_rm_netapp_volume.AzureRMNetAppVolume.get_azure_netapp_volume')
-def test_modify(mock_get, mock_base, client_f, patch_ansible):  # pylint: disable=unused-argument
-    data = set_default_args()
+def test_modify(mock_get, client_f, patch_ansible):  # pylint: disable=unused-argument
+    data = dict(set_default_args())
     data['name'] = 'modify'
     data['size'] = 200
+    data['tags'] = {'added_tag': 'new_tag'}
     set_module_args(data)
     mock_get.side_effect = [
         dict(mount_targets=[dict(ip_address='11.22.33.44')],        # first get
              creation_token='abcd',
+             tags={},
              usage_threshold=0),
         dict(mount_targets=[dict(ip_address='11.22.33.44')],        # get after modify
              creation_token='abcd',
              usage_threshold=10000000)
     ]
-    mock_base.return_value = Mock()
     client_f.return_value = Mock()
     my_obj = volume_module()
     my_obj.azure_auth = Mock(subscription_id='1234')
     my_obj._new_style = True
     my_obj.netapp_client.volumes = MockAzureClient()
     with pytest.raises(AnsibleExitJson) as exc:
-        my_obj.exec_module()
+        # add default args for exec_module
+        data['state'] = 'present'
+        data['debug'] = False
+        my_obj.exec_module(**data)
     assert exc.value.args[0]['changed']
+    print('modify', exc.value.args[0])
     expected_mount_path = '11.22.33.44:/abcd'
     assert exc.value.args[0]['mount_path'] == expected_mount_path
 
 
 @patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.netapp_client')
-@patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.__init__')
 @patch('ansible_collections.netapp.azure.plugins.modules.azure_rm_netapp_volume.AzureRMNetAppVolume.get_azure_netapp_volume')
-def test_modify_exception(mock_get, mock_base, client_f, patch_ansible):    # pylint: disable=unused-argument
-    data = set_default_args()
+def test_modify_exception(mock_get, client_f, patch_ansible):    # pylint: disable=unused-argument
+    data = dict(set_default_args())
     data['name'] = 'modify'
     data['size'] = 200
     set_module_args(data)
@@ -416,23 +411,24 @@ def test_modify_exception(mock_get, mock_base, client_f, patch_ansible):    # py
              creation_token='abcd',
              usage_threshold=10000000)
     ]
-    mock_base.return_value = Mock()
     client_f.return_value = Mock()
     my_obj = volume_module()
     my_obj.azure_auth = Mock(subscription_id='1234')
     my_obj._new_style = True
     my_obj.netapp_client.volumes = MockAzureClientRaise()
     with pytest.raises(AnsibleFailJson) as exc:
-        my_obj.exec_module()
+        # add default args for exec_module
+        data['state'] = 'present'
+        data['debug'] = False
+        my_obj.exec_module(**data)
     expected_msg = 'Error modifying volume'
     assert expected_msg in exc.value.args[0]['msg']
 
 
 @patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.netapp_client')
-@patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.__init__')
 @patch('ansible_collections.netapp.azure.plugins.modules.azure_rm_netapp_volume.AzureRMNetAppVolume.get_azure_netapp_volume')
-def test_modify_not_supported(mock_get, mock_base, client_f, patch_ansible):    # pylint: disable=unused-argument
-    data = set_default_args()
+def test_modify_not_supported(mock_get, client_f, patch_ansible):    # pylint: disable=unused-argument
+    data = dict(set_default_args())
     data['name'] = 'modify'
     data['location'] = 'east'
     set_module_args(data)
@@ -446,23 +442,23 @@ def test_modify_not_supported(mock_get, mock_base, client_f, patch_ansible):
              creation_token='abcd',
              usage_threshold=10000000)
     ]
-    mock_base.return_value = Mock()
     client_f.return_value = Mock()
     my_obj = volume_module()
     my_obj.azure_auth = Mock(subscription_id='1234')
     my_obj._new_style = True
     my_obj.netapp_client.volumes = MockAzureClient()
     with pytest.raises(AnsibleFailJson) as exc:
-        my_obj.exec_module()
+        # add default args for exec_module
+        data['state'] = 'present'
+        data['debug'] = False
+        my_obj.exec_module(**data)
     expected_msg = "Error: the following properties cannot be modified: {'location': 'east'}"
     assert expected_msg in exc.value.args[0]['msg']
 
 
 @patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.netapp_client')
-@patch('ansible_collections.netapp.azure.plugins.module_utils.azure_rm_netapp_common.AzureRMNetAppModuleBase.__init__')
-def test_get_export_policy_rules(mock_base, client_f, patch_ansible):
+def test_get_export_policy_rules(client_f, patch_ansible):
     set_module_args(set_default_args())
-    mock_base.return_value = Mock()
     client_f.return_value = Mock()
     my_obj = volume_module()
     my_obj.netapp_client.volumes = MockAzureClient()
@@ -481,3 +477,25 @@ def test_get_export_policy_rules(mock_base, client_f, patch_ansible):
     rule = vars(rules[0])
     assert rule['nfsv41']
     assert not rule['cifs']
+
+
+def test_dict_from_object():
+    set_module_args(set_default_args())
+    my_obj = volume_module()
+    # just for fun
+    module_dict = my_obj.dict_from_volume_object(my_obj)
+    print('Module dict', module_dict)
+
+    rule_object = Mock()
+    rule_object.ip_address = '10.10.10.10'
+    export_policy_object = Mock()
+    export_policy_object.rules = [rule_object]
+    volume_object = Mock()
+    volume_object.export_policy = export_policy_object
+    volume_dict = my_obj.dict_from_volume_object(volume_object)
+    print('Volume dict', volume_dict)
+    assert 'export_policy' in volume_dict
+    assert 'rules' in volume_dict['export_policy']
+    assert isinstance(volume_dict['export_policy']['rules'], list)
+    assert len(volume_dict['export_policy']['rules']) == 1
+    assert 'ip_address' in volume_dict['export_policy']['rules'][0]
