@@ -1,4 +1,4 @@
-# (c) 2021, NetApp, Inc
+# (c) 2022, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 ''' unit tests Cloudmanager Ansible module: '''
@@ -95,6 +95,8 @@ class TestMyModule(unittest.TestCase):
             'subnet_id': 'subnet-test',
             'svm_password': 'password',
             'refresh_token': 'myrefresh_token',
+            'use_latest_version': False,
+            'ontap_version': 'ONTAP-9.10.0.T1.gcp',
             'is_ha': False,
             'gcp_service_account': 'test_account',
             'data_encryption_type': 'GCP',
@@ -176,6 +178,8 @@ class TestMyModule(unittest.TestCase):
                                                  get_tenant, wait_on_completion, get_token):
         data = self.set_args_create_cloudmanager_cvo_gcp()
         data['is_ha'] = True
+        data['license_type'] = 'ha-capacity-paygo'
+        data['capacity_package_name'] = 'Essential'
         data['subnet0_node_and_data_connectivity'] = 'default'
         data['subnet1_cluster_connectivity'] = 'subnet2'
         data['subnet2_ha_connectivity'] = 'subnet3'
@@ -356,6 +360,7 @@ class TestMyModule(unittest.TestCase):
         assert exc.value.args[0]['changed']
 
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp.CloudManagerRestAPI.get_token')
+    @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.update_instance_license_type')
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.update_tier_level')
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.update_cvo_tags')
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.update_svm_password')
@@ -363,10 +368,10 @@ class TestMyModule(unittest.TestCase):
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.get_working_environment_property')
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.get_working_environment_details_by_name')
     def test_change_cloudmanager_cvo_gcp(self, get_cvo, get_property, get_details, update_svm_password, update_cvo_tags,
-                                         update_tier_level, get_token):
+                                         update_tier_level, update_instance_license_type, get_token):
         set_module_args(self.set_args_create_cloudmanager_cvo_gcp())
 
-        modify = ['svm_password', 'gcp_labels', 'tier_level']
+        modify = ['svm_password', 'gcp_labels', 'tier_level', 'instance_type']
 
         my_cvo = {
             'name': 'TestA',
@@ -421,22 +426,30 @@ class TestMyModule(unittest.TestCase):
                 update_cvo_tags.return_value = True, None
             elif item == 'tier_level':
                 update_tier_level.return_value = True, None
+            elif item == 'instance_type':
+                update_instance_license_type.return_value = True, None
 
         with pytest.raises(AnsibleExitJson) as exc:
             my_obj.apply()
         print('Info: test_change_cloudmanager_cvo_gcp: %s' % repr(exc.value))
 
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp.CloudManagerRestAPI.get_token')
+    @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.update_instance_license_type')
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.update_tier_level')
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.update_cvo_tags')
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.update_svm_password')
+    @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.upgrade_ontap_image')
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.get_working_environment_details')
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.get_working_environment_property')
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.get_working_environment_details_by_name')
-    def test_change_cloudmanager_cvo_gcp_ha(self, get_cvo, get_property, get_details, update_svm_password,
-                                            update_cvo_tags, update_tier_level, get_token):
+    def test_change_cloudmanager_cvo_gcp_ha(self, get_cvo, get_property, get_details, upgrade_ontap_image, update_svm_password,
+                                            update_cvo_tags, update_tier_level, update_instance_license_type, get_token):
         data = self.set_args_create_cloudmanager_cvo_gcp()
         data['is_ha'] = True
+        data['svm_password'] = 'newpassword'
+        data['update_svm_password'] = True
+        data['ontap_version'] = 'ONTAP-9.10.1P3.T1.gcpha'
+        data['upgrade_ontap_version'] = True
         data['subnet0_node_and_data_connectivity'] = 'default'
         data['subnet1_cluster_connectivity'] = 'subnet2'
         data['subnet2_ha_connectivity'] = 'subnet3'
@@ -448,9 +461,10 @@ class TestMyModule(unittest.TestCase):
         data['platform_serial_number_node1'] = '12345678'
         data['platform_serial_number_node2'] = '23456789'
         data['license_type'] = 'gcp-ha-cot-premium-byol'
+        data['instance_type'] = 'n1-standard-8'
         set_module_args(data)
 
-        modify = ['svm_password', 'gcp_labels', 'tier_level']
+        modify = ['svm_password', 'gcp_labels', 'tier_level', 'ontap_version', 'instance_type', 'license_type']
 
         my_cvo = {
             'name': 'TestA',
@@ -469,6 +483,9 @@ class TestMyModule(unittest.TestCase):
                             'licenseType': {'capacityLimit': {'size': 10.0, 'unit': 'TB'},
                                             'name': 'Cloud Volumes ONTAP Standard'},
                             'ontapVersion': '9.10.0.T1',
+                            'upgradeVersions': [{'autoUpdateAllowed': False,
+                                                 'imageVersion': 'ONTAP-9.10.1P3',
+                                                 'lastModified': 1634467078000}],
                             'writingSpeedState': 'NORMAL'},
                         'providerProperties': {
                             'regionName': 'us-west1',
@@ -492,7 +509,8 @@ class TestMyModule(unittest.TestCase):
                        'ontapClusterProperties': None,
                        'publicId': 'test',
                        'status': None,
-                       'userTags': {'key1': 'value1', 'partner-platform-serial-number': '90920140000000001019'},
+                       'userTags': {'key1': 'value1', 'partner-platform-serial-number': '90920140000000001019',
+                                    'gcp_resource_id': '14004944518802780827', 'count-down': '3'},
                        'workingEnvironmentType': 'VSA'}
         get_details.return_value = cvo_details, None
         get_token.return_value = 'test', 'test'
@@ -505,6 +523,10 @@ class TestMyModule(unittest.TestCase):
                 update_cvo_tags.return_value = True, None
             elif item == 'tier_level':
                 update_tier_level.return_value = True, None
+            elif item == 'ontap_version':
+                upgrade_ontap_image.return_value = True, None
+            elif item == 'instance_type':
+                update_instance_license_type.return_value = True, None
 
         with pytest.raises(AnsibleExitJson) as exc:
             my_obj.apply()
