@@ -1,13 +1,14 @@
 ''' unit tests ONTAP Ansible module: na_ontap_quotas '''
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
-import json
 import pytest
 
-from ansible.module_utils import basic
-from ansible.module_utils._text import to_bytes
 from ansible_collections.netapp.ontap.tests.unit.compat.mock import patch
 import ansible_collections.netapp.ontap.plugins.module_utils.netapp as netapp_utils
+from ansible_collections.netapp.ontap.tests.unit.plugins.module_utils.ansible_mocks import set_module_args,\
+    AnsibleFailJson, AnsibleExitJson, patch_ansible
+from ansible_collections.netapp.ontap.tests.unit.framework.mock_rest_and_zapi_requests import patch_request_and_invoke
+
 
 from ansible_collections.netapp.ontap.plugins.modules.na_ontap_qtree \
     import NetAppOntapQTree as qtree_module  # module under test
@@ -41,41 +42,6 @@ SRR = {
 }
 
 
-def set_module_args(args):
-    """prepare arguments so that they will be picked up during module creation"""
-    args = json.dumps({'ANSIBLE_MODULE_ARGS': args})
-    basic._ANSIBLE_ARGS = to_bytes(args)  # pylint: disable=protected-access
-
-
-class AnsibleExitJson(Exception):
-    """Exception class to be raised by module.exit_json and caught by the test case"""
-
-
-class AnsibleFailJson(Exception):
-    """Exception class to be raised by module.fail_json and caught by the test case"""
-
-
-def exit_json(*args, **kwargs):  # pylint: disable=unused-argument
-    """function to patch over exit_json; package return data into an exception"""
-    if 'changed' not in kwargs:
-        kwargs['changed'] = False
-    raise AnsibleExitJson(kwargs)
-
-
-def fail_json(*args, **kwargs):  # pylint: disable=unused-argument
-    """function to patch over fail_json; package return data into an exception"""
-    kwargs['failed'] = True
-    raise AnsibleFailJson(kwargs)
-
-
-@pytest.fixture(name='patch_ansible_mod')
-def fixture_patch_ansible():
-    with patch.multiple(basic.AnsibleModule,
-                        exit_json=exit_json,
-                        fail_json=fail_json) as mocks:
-        yield mocks
-
-
 class MockONTAPConnection(object):
     ''' mock server connection to ONTAP host '''
 
@@ -139,7 +105,7 @@ def set_default_args(use_rest=None):
         'flexvol_name': flexvol_name,
         'export_policy': export_policy,
         'security_style': security_style,
-        'unix_permissions': mode
+        'unix_permissions': mode,
     })
 
     if use_rest is not None:
@@ -158,7 +124,7 @@ def get_qtree_mock_object(cx_type='zapi', kind=None):
     return qtree_obj
 
 
-def test_module_fail_when_required_args_missing(patch_ansible_mod):     # pylint: disable=unused-argument
+def test_module_fail_when_required_args_missing(patch_ansible):     # pylint: disable=unused-argument
     ''' required arguments are reported as errors '''
     with pytest.raises(AnsibleFailJson) as exc:
         set_module_args({})
@@ -185,7 +151,7 @@ def test_ensure_get_called_existing():
 
 
 @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_qtree.NetAppOntapQTree.create_qtree')
-def test_successful_create(create_qtree, patch_ansible_mod):    # pylint: disable=unused-argument
+def test_successful_create(create_qtree, patch_ansible):    # pylint: disable=unused-argument
     ''' creating qtree and testing idempotency '''
     set_module_args(set_default_args(use_rest='Never'))
     my_obj = qtree_module()
@@ -206,7 +172,7 @@ def test_successful_create(create_qtree, patch_ansible_mod):    # pylint: disabl
 
 
 @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_qtree.NetAppOntapQTree.delete_qtree')
-def test_successful_delete(delete_qtree, patch_ansible_mod):    # pylint: disable=unused-argument
+def test_successful_delete(delete_qtree, patch_ansible):    # pylint: disable=unused-argument
     ''' deleting qtree and testing idempotency '''
     data = set_default_args(use_rest='Never')
     data['state'] = 'absent'
@@ -228,7 +194,7 @@ def test_successful_delete(delete_qtree, patch_ansible_mod):    # pylint: disabl
 
 
 @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_qtree.NetAppOntapQTree.modify_qtree')
-def test_successful_modify(modify_qtree, patch_ansible_mod):    # pylint: disable=unused-argument
+def test_successful_modify(modify_qtree, patch_ansible):    # pylint: disable=unused-argument
     ''' modifying qtree and testing idempotency '''
     data = set_default_args(use_rest='Never')
     data['export_policy'] = 'test'
@@ -253,7 +219,7 @@ def test_successful_modify(modify_qtree, patch_ansible_mod):    # pylint: disabl
 
 @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_qtree.NetAppOntapQTree.get_qtree')
 @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_qtree.NetAppOntapQTree.rename_qtree')
-def test_failed_rename(rename_qtree, get_qtree, patch_ansible_mod):     # pylint: disable=unused-argument
+def test_failed_rename(rename_qtree, get_qtree, patch_ansible):     # pylint: disable=unused-argument
     ''' creating qtree and testing idempotency '''
     get_qtree.side_effect = [None, None]
     data = set_default_args(use_rest='Never')
@@ -270,7 +236,7 @@ def test_failed_rename(rename_qtree, get_qtree, patch_ansible_mod):     # pylint
 
 @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_qtree.NetAppOntapQTree.get_qtree')
 @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_qtree.NetAppOntapQTree.rename_qtree')
-def test_successful_rename(rename_qtree, get_qtree, patch_ansible_mod):     # pylint: disable=unused-argument
+def test_successful_rename(rename_qtree, get_qtree, patch_ansible):     # pylint: disable=unused-argument
     ''' creating qtree and testing idempotency '''
     data = set_default_args(use_rest='Never')
     data['from_name'] = 'ansible_old'
@@ -298,7 +264,7 @@ def test_successful_rename(rename_qtree, get_qtree, patch_ansible_mod):     # py
     assert not exc.value.args[0]['changed']
 
 
-def test_if_all_methods_catch_exception(patch_ansible_mod):     # pylint: disable=unused-argument
+def test_if_all_methods_catch_exception(patch_ansible):     # pylint: disable=unused-argument
     data = set_default_args(use_rest='Never')
     data['from_name'] = 'ansible'
     set_module_args(data)
@@ -320,7 +286,7 @@ def test_if_all_methods_catch_exception(patch_ansible_mod):     # pylint: disabl
 
 
 @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
-def test_rest_error(mock_request, patch_ansible_mod):   # pylint: disable=unused-argument
+def test_rest_error(mock_request, patch_ansible):   # pylint: disable=unused-argument
     data = set_default_args()
     set_module_args(data)
     mock_request.side_effect = [
@@ -334,7 +300,7 @@ def test_rest_error(mock_request, patch_ansible_mod):   # pylint: disable=unused
 
 
 @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
-def test_successful_create_rest(mock_request, patch_ansible_mod):   # pylint: disable=unused-argument
+def test_successful_create_rest(mock_request, patch_ansible):   # pylint: disable=unused-argument
     data = set_default_args()
     set_module_args(data)
     mock_request.side_effect = [
@@ -349,7 +315,7 @@ def test_successful_create_rest(mock_request, patch_ansible_mod):   # pylint: di
 
 
 @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
-def test_idempotent_create_rest(mock_request, patch_ansible_mod):   # pylint: disable=unused-argument
+def test_idempotent_create_rest(mock_request, patch_ansible):   # pylint: disable=unused-argument
     data = set_default_args()
     set_module_args(data)
     mock_request.side_effect = [
@@ -363,7 +329,7 @@ def test_idempotent_create_rest(mock_request, patch_ansible_mod):   # pylint: di
 
 
 @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
-def test_successful_delete_rest(mock_request, patch_ansible_mod):   # pylint: disable=unused-argument
+def test_successful_delete_rest(mock_request, patch_ansible):   # pylint: disable=unused-argument
     data = set_default_args()
     data['state'] = 'absent'
     set_module_args(data)
@@ -379,7 +345,7 @@ def test_successful_delete_rest(mock_request, patch_ansible_mod):   # pylint: di
 
 
 @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
-def test_idempotent_delete_rest(mock_request, patch_ansible_mod):   # pylint: disable=unused-argument
+def test_idempotent_delete_rest(mock_request, patch_ansible):   # pylint: disable=unused-argument
     data = set_default_args()
     data['state'] = 'absent'
     set_module_args(data)
@@ -394,7 +360,7 @@ def test_idempotent_delete_rest(mock_request, patch_ansible_mod):   # pylint: di
 
 
 @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
-def test_successful_modify_rest(mock_request, patch_ansible_mod):   # pylint: disable=unused-argument
+def test_successful_modify_rest(mock_request, patch_ansible):   # pylint: disable=unused-argument
     data = set_default_args()
     data['state'] = 'present'
     data['unix_permissions'] = 'abcde'
@@ -411,7 +377,7 @@ def test_successful_modify_rest(mock_request, patch_ansible_mod):   # pylint: di
 
 
 @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
-def test_idempotent_modify_rest(mock_request, patch_ansible_mod):   # pylint: disable=unused-argument
+def test_idempotent_modify_rest(mock_request, patch_ansible):   # pylint: disable=unused-argument
     data = set_default_args()
     data['state'] = 'present'
     set_module_args(data)
@@ -426,7 +392,7 @@ def test_idempotent_modify_rest(mock_request, patch_ansible_mod):   # pylint: di
 
 
 @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
-def test_successful_rename_rest(mock_request, patch_ansible_mod):   # pylint: disable=unused-argument
+def test_successful_rename_rest(mock_request, patch_ansible):   # pylint: disable=unused-argument
     data = set_default_args()
     data['state'] = 'present'
     data['from_name'] = 'abcde'
@@ -445,7 +411,7 @@ def test_successful_rename_rest(mock_request, patch_ansible_mod):   # pylint: di
 
 
 @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
-def test_successful_rename_rest_idempotent(mock_request, patch_ansible_mod):    # pylint: disable=unused-argument
+def test_successful_rename_rest_idempotent(mock_request, patch_ansible):    # pylint: disable=unused-argument
     data = set_default_args()
     data['state'] = 'present'
     data['from_name'] = 'abcde'
@@ -463,7 +429,7 @@ def test_successful_rename_rest_idempotent(mock_request, patch_ansible_mod):
 
 
 @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
-def test_successful_rename_and_modify_rest(mock_request, patch_ansible_mod):    # pylint: disable=unused-argument
+def test_successful_rename_and_modify_rest(mock_request, patch_ansible):    # pylint: disable=unused-argument
     data = set_default_args()
     data['state'] = 'present'
     data['from_name'] = 'abcde'
