@@ -38,16 +38,16 @@ options:
     size_unit:
         description:
             - The unit used to interpret the size parameter
+            - pct unit defines a percent of total usable storage pool size.
         type: str
-        choices: ["bytes", "b", "kb", "mb", "gb", "tb", "pb", "eb", "zb", "yb"]
+        choices: ["bytes", "b", "kb", "mb", "gb", "tb", "pb", "eb", "zb", "yb", "pct"]
         default: "gb"
     size:
         description:
             - Required only when I(state=="present").
             - Size of the volume in I(size_unit).
             - Size of the virtual volume in the case of a thin volume in I(size_unit).
-            - Maximum virtual volume size of a thin provisioned volume is 256tb; however other OS-level restrictions may
-              exist.
+            - Maximum virtual volume size of a thin provisioned volume is 256tb; however other OS-level restrictions may exist.
         type: float
         required: true
     segment_size_kb:
@@ -82,7 +82,7 @@ options:
         description:
             - This is the maximum amount the thin volume repository will be allowed to grow.
             - Only has significance when I(thin_volume_expansion_policy=="automatic").
-            - When the percentage I(thin_volume_repo_size) of I(thin_volume_max_repo_size) exceeds
+            - When the pct I(thin_volume_repo_size) of I(thin_volume_max_repo_size) exceeds
               I(thin_volume_growth_alert_threshold) then a warning will be issued and the storage array will execute
               the I(thin_volume_expansion_policy) policy.
             - Expansion operations when I(thin_volume_expansion_policy=="automatic") will increase the maximum
@@ -106,7 +106,7 @@ options:
     thin_volume_growth_alert_threshold:
         description:
             - This is the thin provision repository utilization threshold (in percent).
-            - When the percentage of used storage of the maximum repository size exceeds this value then a alert will
+            - When the pct of used storage of the maximum repository size exceeds this value then a alert will
               be issued and the I(thin_volume_expansion_policy) will be executed.
             - Values must be between or equal to 10 and 99.
         type: int
@@ -153,6 +153,12 @@ options:
         type: bool
         default: true
         required: false
+    write_cache_mirror_enable:
+        description:
+            - Indicates whether write cache mirroring should be enabled.
+        type: bool
+        default: true
+        required: false
     cache_without_batteries:
         description:
             - Indicates whether caching should be used without battery backup.
@@ -170,15 +176,33 @@ options:
             - Existing workloads can be retrieved using M(na_santricity_facts).
         type: str
         required: false
-    metadata:
+    workload_metadata:
         description:
             - Dictionary containing meta data for the use, user, location, etc of the volume (dictionary is arbitrarily
               defined for whatever the user deems useful)
             - When I(workload_name) exists on the storage array but the metadata is different then the workload
               definition will be updated. (Changes will update all associated volumes!)
             - I(workload_name) must be specified when I(metadata) are defined.
+            - Dictionary key cannot be longer than 16 characters
+            - Dictionary values cannot be longer than 60 characters
         type: dict
         required: false
+        aliases:
+            - metadata
+    volume_metadata:
+        description:
+            - Dictionary containing metadata for the volume itself.
+            - Dictionary key cannot be longer than 14 characters
+            - Dictionary values cannot be longer than 240 characters
+        type: dict
+        required: false
+    allow_expansion:
+        description:
+            - Allows volume size to expand to meet the required specification.
+            - Warning, when I(allows_expansion==false) and the existing volume needs to be expanded the module will continue with a warning.
+        type: bool
+        default: false
+        required: false
     wait_for_initialization:
         description:
             - Forces the module to wait for expansion operations to complete before continuing.
@@ -278,13 +302,16 @@ from ansible.module_utils._text import to_native
 
 class NetAppESeriesVolume(NetAppESeriesModule):
     VOLUME_CREATION_BLOCKING_TIMEOUT_SEC = 300
+    MAXIMUM_VOLUME_METADATA_KEY_LENGTH = 14
+    MAXIMUM_VOLUME_METADATA_VALUE_LENGTH = 240
+    MAXIMUM_VOLUME_METADATA_VALUE_SEGMENT_LENGTH = 60
 
     def __init__(self):
         ansible_options = dict(
             state=dict(choices=["present", "absent"], default="present"),
             name=dict(required=True, type="str"),
             storage_pool_name=dict(type="str"),
-            size_unit=dict(default="gb", choices=["bytes", "b", "kb", "mb", "gb", "tb", "pb", "eb", "zb", "yb"], type="str"),
+            size_unit=dict(default="gb", choices=["bytes", "b", "kb", "mb", "gb", "tb", "pb", "eb", "zb", "yb", "pct"], type="str"),
             size=dict(type="float"),
             segment_size_kb=dict(type="int", default=128, required=False),
             owning_controller=dict(type="str", choices=["A", "B"], required=False),
@@ -298,9 +325,12 @@ class NetAppESeriesVolume(NetAppESeriesModule):
             read_cache_enable=dict(type="bool", default=True),
             read_ahead_enable=dict(type="bool", default=True),
             write_cache_enable=dict(type="bool", default=True),
+            write_cache_mirror_enable=dict(type="bool", default=True),
             cache_without_batteries=dict(type="bool", default=False),
             workload_name=dict(type="str", required=False),
-            metadata=dict(type="dict", require=False),
+            workload_metadata=dict(type="dict", require=False, aliases=["metadata"]),
+            volume_metadata=dict(type="dict", require=False),
+            allow_expansion=dict(type="bool", default=False),
             wait_for_initialization=dict(type="bool", default=False))
 
         required_if = [
@@ -320,7 +350,12 @@ class NetAppESeriesVolume(NetAppESeriesModule):
         self.size_unit = args["size_unit"]
         self.segment_size_kb = args["segment_size_kb"]
         if args["size"]:
-            self.size_b = self.convert_to_aligned_bytes(args["size"])
+            if self.size_unit == "pct":
+                if args["thin_provision"]:
+                    self.module.fail_json(msg="'pct' is an invalid size unit for thin provisioning! Array [%s]." % self.ssid)
+                self.size_percent = args["size"]
+            else:
+                self.size_b = self.convert_to_aligned_bytes(args["size"])
 
         self.owning_controller_id = None
         if args["owning_controller"]:
@@ -329,6 +364,7 @@ class NetAppESeriesVolume(NetAppESeriesModule):
         self.read_cache_enable = args["read_cache_enable"]
         self.read_ahead_enable = args["read_ahead_enable"]
         self.write_cache_enable = args["write_cache_enable"]
+        self.write_cache_mirror_enable = args["write_cache_mirror_enable"]
         self.ssd_cache_enabled = args["ssd_cache_enabled"]
         self.cache_without_batteries = args["cache_without_batteries"]
         self.data_assurance_enabled = args["data_assurance_enabled"]
@@ -345,21 +381,43 @@ class NetAppESeriesVolume(NetAppESeriesModule):
             self.thin_volume_max_repo_size_b = self.convert_to_aligned_bytes(args["thin_volume_max_repo_size"])
 
         self.workload_name = args["workload_name"]
-        self.metadata = args["metadata"]
+        self.allow_expansion = args["allow_expansion"]
         self.wait_for_initialization = args["wait_for_initialization"]
 
         # convert metadata to a list of dictionaries containing the keys "key" and "value" corresponding to
         #   each of the workload attributes dictionary entries
-        metadata = []
-        if self.metadata:
+        self.metadata = []
+        if self.state == "present" and args["workload_metadata"]:
             if not self.workload_name:
-                self.module.fail_json(msg="When metadata is specified then the name for the workload must be specified."
-                                          " Array [%s]." % self.ssid)
-            for key in self.metadata.keys():
-                metadata.append(dict(key=key, value=self.metadata[key]))
-            self.metadata = metadata
+                self.module.fail_json(msg="When metadata is specified then the name for the workload must be specified. Array [%s]." % self.ssid)
 
-        if self.thin_provision:
+            for key, value in args["workload_metadata"].items():
+                self.metadata.append({"key": key, "value": value})
+
+        self.volume_metadata = []
+        if self.state == "present" and args["volume_metadata"]:
+            for key, value in args["volume_metadata"].items():
+                key, value = str(key), str(value)
+
+                if len(key) > self.MAXIMUM_VOLUME_METADATA_KEY_LENGTH:
+                    self.module.fail_json(msg="Volume metadata keys must be less than %s characters long. Array [%s]."
+                                              % (str(self.MAXIMUM_VOLUME_METADATA_KEY_LENGTH), self.ssid))
+
+                if len(value) > self.MAXIMUM_VOLUME_METADATA_VALUE_LENGTH:
+                    self.module.fail_json(msg="Volume metadata values must be less than %s characters long. Array [%s]."
+                                              % (str(self.MAXIMUM_VOLUME_METADATA_VALUE_LENGTH), self.ssid))
+
+                if value:
+                    for index, start in enumerate(range(0, len(value), self.MAXIMUM_VOLUME_METADATA_VALUE_SEGMENT_LENGTH)):
+                        if len(value) > start + self.MAXIMUM_VOLUME_METADATA_VALUE_SEGMENT_LENGTH:
+                            self.volume_metadata.append({"key": "%s~%s" % (key, str(index)),
+                                                         "value": value[start:start + self.MAXIMUM_VOLUME_METADATA_VALUE_SEGMENT_LENGTH]})
+                        else:
+                            self.volume_metadata.append({"key": "%s~%s" % (key, str(index)), "value": value[start:len(value)]})
+                else:
+                    self.volume_metadata.append({"key": "%s~0" % key, "value": ""})
+
+        if self.state == "present" and self.thin_provision:
             if not self.thin_volume_max_repo_size_b:
                 self.thin_volume_max_repo_size_b = self.size_b
 
@@ -586,7 +644,8 @@ class NetAppESeriesVolume(NetAppESeriesModule):
         change = False
         request_body = dict(flashCache=self.ssd_cache_enabled, metaTags=[],
                             cacheSettings=dict(readCacheEnable=self.read_cache_enable,
-                                               writeCacheEnable=self.write_cache_enable))
+                                               writeCacheEnable=self.write_cache_enable,
+                                               mirrorEnable=self.write_cache_mirror_enable))
 
         # check for invalid modifications
         if self.segment_size_kb * 1024 != int(self.volume_detail["segmentSize"]):
@@ -596,6 +655,7 @@ class NetAppESeriesVolume(NetAppESeriesModule):
         # common thick/thin volume properties
         if (self.read_cache_enable != self.volume_detail["cacheSettings"]["readCacheEnable"] or
                 self.write_cache_enable != self.volume_detail["cacheSettings"]["writeCacheEnable"] or
+                self.write_cache_mirror_enable != self.volume_detail["cacheSettings"]["mirrorEnable"] or
                 self.ssd_cache_enabled != self.volume_detail["flashCached"]):
             change = True
 
@@ -604,12 +664,21 @@ class NetAppESeriesVolume(NetAppESeriesModule):
             change = True
             request_body.update(dict(owningControllerId=self.owning_controller_id))
 
-        if self.workload_name:
-            request_body.update(dict(metaTags=[dict(key="workloadId", value=self.workload_id),
-                                               dict(key="volumeTypeId", value="volume")]))
-            if {"key": "workloadId", "value": self.workload_id} not in self.volume_detail["metadata"]:
+        # volume meta tags
+        request_body["metaTags"].extend(self.volume_metadata)
+        for entry in self.volume_metadata:
+            if entry not in self.volume_detail["metadata"]:
                 change = True
-        elif self.volume_detail["metadata"]:
+
+        if self.workload_name:
+            request_body["metaTags"].extend([{"key": "workloadId", "value": self.workload_id},
+                                             {"key": "volumeTypeId", "value": "volume"}])
+
+            if ({"key": "workloadId", "value": self.workload_id} not in self.volume_detail["metadata"] or
+                    {"key": "volumeTypeId", "value": "volume"} not in self.volume_detail["metadata"]):
+                change = True
+
+        if len(self.volume_detail["metadata"]) != len(request_body["metaTags"]):
             change = True
 
         # thick/thin volume specific properties
@@ -667,6 +736,10 @@ class NetAppESeriesVolume(NetAppESeriesModule):
             request_body.update(dict(sizeUnit="bytes", expansionSize=self.size_b))
             self.module.log("Volume storage capacities have been expanded.")
 
+        if request_body and not self.allow_expansion:
+            self.module.warn("Expansion not allowed! Change allow_expansion flag to true to allow volume expansions. Array Id [%s]." % self.ssid)
+            return dict()
+
         return request_body
 
     def create_volume(self):
@@ -674,6 +747,9 @@ class NetAppESeriesVolume(NetAppESeriesModule):
         body = dict(name=self.name, poolId=self.pool_detail["id"], sizeUnit="bytes",
                     dataAssuranceEnabled=self.data_assurance_enabled)
 
+        if self.volume_metadata:
+            body.update({"metaTags": self.volume_metadata})
+
         if self.thin_provision:
             body.update(dict(virtualSize=self.size_b,
                              repositorySize=self.thin_volume_repo_size_b,
@@ -783,6 +859,11 @@ class NetAppESeriesVolume(NetAppESeriesModule):
         self.volume_detail = self.get_volume()
         self.pool_detail = self.get_storage_pool()
 
+        if self.pool_detail and self.size_unit == "pct":
+            space_mb = round(float(self.pool_detail["totalRaidedSpace"]), -8) / 1024 ** 2 - 100
+            self.size_unit = "mb"
+            self.size_b = self.convert_to_aligned_bytes(space_mb * (self.size_percent / 100))
+
         # Determine whether changes need to be applied to existing workload tags
         if self.state == 'present' and self.update_workload_tags(check_mode=True):
             change = True
@@ -793,7 +874,10 @@ class NetAppESeriesVolume(NetAppESeriesModule):
                 change = True
 
             elif self.state == 'present':
-                if self.get_expand_volume_changes() or self.get_volume_property_changes():
+                # Must check the property changes first as it makes sure the segment size has no change before
+                # using the size to determine if the volume expansion is needed which will cause an irrelevant 
+                # error message to show up.
+                if self.get_volume_property_changes() or self.get_expand_volume_changes():
                     change = True
 
         elif self.state == 'present':
