@@ -98,7 +98,7 @@ def main():
     if module.params['fetch_nested'] or module.params['nested_attributes']:
         module.deprecate(
             "The 'fetch_nested' and 'nested_attributes' are deprecated please use 'follow' parameter",
-            version='2.0.0',
+            version='3.0.0',
             collection_name='ovirt.ovirt'
         )
 
@@ -112,9 +112,15 @@ def main():
 
         # Find the unregistered Template we want to register:
         if module.params.get('unregistered'):
-            templates = templates_service.list(unregistered=True)
+            templates = templates_service.list(
+                unregistered=True,
+                follow=",".join(module.params['follow'])
+            )
         else:
-            templates = templates_service.list(max=module.params['max'])
+            templates = templates_service.list(
+                max=module.params['max'],
+                follow=",".join(module.params['follow'])
+            )
         result = dict(
             ovirt_storage_templates=[
                 get_dict_of_struct(
