@@ -88,19 +88,23 @@ from ansible_collections.ovirt.ovirt.plugins.module_utils.ovirt import (
 
 def main():
     argument_spec = ovirt_info_full_argument_spec(
-        filter_keys=dict(default=None, type='list', elements='str'),
+        filter_keys=dict(default=None, type='list', elements='str', no_log=True),
         name=dict(default=None, type='str'),
     )
     module = AnsibleModule(argument_spec)
     check_sdk(module)
     if module.params['fetch_nested'] or module.params['nested_attributes']:
-        module.deprecate("The 'fetch_nested' and 'nested_attributes' are deprecated please use 'follow' parameter", version='2.0')
+        module.deprecate(
+            "The 'fetch_nested' and 'nested_attributes' are deprecated please use 'follow' parameter",
+            version='3.0.0',
+            collection_name='ovirt.ovirt'
+        )
 
     try:
         auth = module.params.pop('auth')
         connection = create_connection(auth)
         operating_systems_service = connection.system_service().operating_systems_service()
-        operating_systems = operating_systems_service.list()
+        operating_systems = operating_systems_service.list(follow=",".join(module.params['follow']))
         if module.params['name']:
             operating_systems = filter(lambda x: x.name == module.params['name'], operating_systems)
         result = dict(
