@@ -48,7 +48,7 @@ extends_documentation_fragment:
 
 EXAMPLES = r"""
 - name: Sign EULA for FlashArray
-  purefa_eula:
+  purestorage.flasharray.purefa_eula:
     company: "ACME Storage, Inc."
     name: "Fred Bloggs"
     title: "Storage Manager"
@@ -77,9 +77,9 @@ def set_eula(module, array):
     except Exception:
         module.fail_json(msg="Failed to get current EULA")
     if (
-        current_eula["company"] != module.params["company"]
-        or current_eula["title"] != module.params["title"]
-        or current_eula["name"] != module.params["name"]
+        current_eula["acceptance"]["company"] != module.params["company"]
+        or current_eula["acceptance"]["title"] != module.params["title"]
+        or current_eula["acceptance"]["name"] != module.params["name"]
     ):
         try:
             changed = True
